package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut



__DATA__
M35J0``,````$````__\``+@`````````0```````````````````````````
M````````````````````^`````X?N@X`M`G-(;@!3,TA5&AI<R!P<F]G<F%M
M(&-A;FYO="!B92!R=6X@:6X@1$]3(&UO9&4N#0T*)``````````-)82,243J
MWTE$ZM])1.K?RECDWTM$ZM\F6^#?0D3JWR9;[M]+1.K?RDRWWTU$ZM\R6.;?
M2T3JWTE$Z]\;1.K?MF3NWTI$ZM]_8N#?2T3JW_%"[-](1.K?4FEC:$E$ZM\`
M``````````````````````````````!010``3`$$`!XM*T@``````````.``
M#P$+`08``#````"@````````(#H````0````0`````!````0````$```!```
M```````$``````````#@````$```PZD!``,``````!```!``````$```$```
M`````!```````````````,2?``!D`````,```-`1````````````````````
M```````````````P00``'```````````````````````````````````````
M````````````````````0```+`$`````````````````````````````````
M`"YT97AT````7"L````0````,````!```````````````````"```&`N<F1A
M=&$``,AE````0````'````!```````````````````!```!`+F1A=&$```!D
M!````+`````0````L```````````````````0```P"YR<W)C````T!$```#`
M````(````,```````````````````$```,``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`%:^B$%``%9H(#E``&AL04``Z`0I``!0Z/@H``"#Q!!6:`XY0`!H5$%``.CK
M*```4.C?*```@\007L-5B^R![`@$``!35E=HL$%``.BH`0``B47\C87X^___
MQP0D``0``#/;4%/_%1!`0`"%P`^%3`$``/\U$+!``(MU"%;_%81`0`!9687`
M5G03:*!!0`#H\P$``%F+QEGI5P$``.@U*0``_S44L$``BSV,0$``B47X_W4,
M_]>#Q`R+\#OS#X0?`0``.!YU!;Z<04``.5W\=!-6_W7\Z/<H``!9A<!9#X3+
M````5NCM*```BE0P_UF+#1"P0``Z$74*2(@<!HI4!O_K[(M5^/]U"(U$$`$]
M``0```^-S0```%%6C87X^___:)1!0`!0_Q640$``Z.HG``!0Z/8G``"+,.C=
M)P``4.CC)P``@\0<4(V%^/O__U#HQR<``%#HTR<``%G_,/]64(/$#(7`=4CH
MKR<``%#HM2<``&:+0`999B4`\&8]`(!U+NB5)P``4.BA)P``BS!9C87X^___
M:@%0Z'XG``!0Z(HG``!9_S#_%H/$#(7`=!#_-12P0`!3_]=96>GZ_O__C87X
M^___4&B@04``Z+<```"-A?C[__]0_Q5$0$``@\0,ZQ+_=0AHH$%``.B8````
MBT4(65E?7EO)PU6+[(U%"%#_=0CH!````%E97<-5B^Q14U:+=0A7A?9T9HL=
M@$!``/_3@S@`=%F*#HO&A,ET"X#Y/70&BD@!0.OQ*\:)1?S_TXLPBSZ%_W0W
M_W7\_W4(5_\50$!``(/$#(7`=0F+1?R`/`<]=`6#Q@3KV/_3*S"+10S!_@*)
M,(M%_(U$!P'K`C/`7UY;R<-5B^Q148M%#(`X/74#_T4,4U97_W4,Z#4G``"+
M70B)1?B-1?Q04^A:____BS6`0$``B_B#Q`R%_W0B5^@0)P``.T7X60^"RP``
M`(M-#(H!B`='083`=?;I/`$``/_6BP`S_S/).0AT!H/`!$?K]CD-1+1``'1`
MZ!DF``!0Z"LF``"+&%F-!+T(````4/_6_S#H_R4``%#H$28``%G_,/]3!(/$
M#(O8_]:)&/_6@S@`=57IL0```,<%1+1```$```#HSR4``%#HX24``(L868T$
MO0@```!0Z+DE``!0Z,LE``!9_S#_$XO8687;671YB\?!X`)0_];_,%/_%7Q`
M0`"#Q`S_UHD8_]:+`(M="(-DN`0`B7W\B@.+^X3`=`H\/70&BD<!1^ORZ&@E
M``!0Z'HE``"+$(M%^"O[68E5"(U$!P)0Z$TE``!0Z%\E``!9_S"+10C_$%F+
M^%G_UHL`BTW\A?^)/(AU!8/(_^LN_]:+`(M-_(L$B(H+0X3)B`AT"(#Y/70#
M0.OOBU4,Q@`]0(H*B`A`0H3)=?8SP%]>6\G#BT0D!%:+\(O(B@"$P'07BQ40
ML$``BA(ZPG4#C7$!BD$!083`=?&+QE[#5HMT)`B%]G1O@#X`=&I6Z',E``"-
M1##_68L-$+!``#O&=A:*$3@0=05(.\9W]SO&=@DX$'0#2.OU.\9U"8H`.@%T
M-5'K-T@[QG8&BA`Z$73U*\:-2`*!^0`$``!V!#/`7L-`4%:^/+!``%;_%7A`
M0`"#Q`R+QE[#:)Q!0`#_%41`0`!97L-5B^R#["135E=J"%F^A$)``(U]W&AT
M0D``\Z5FI>@)`0``QP0D:$)``.C]````N[!!0`!3Z/(```"^7$)``%;HYP``
M`+]00D``5^C<````:$1"0`#HT@```&B@04``Z,@```!H.$)``.B^````:"Q"
M0`#HM````&@80D``Z*+\__^#Q"2%P'0)4%?H(OW__UE9:`1"0`#HB/S__X7`
M670-4&CX04``Z`;]__]966CH04``Z&S\__^%P%ET"U!3Z.[\__]96>M.:-1!
M0`#H4OS__X7`670$4%;KY&C,04``Z!TD``"_P$%``(U<!>A7Z`XD``!05U/_
M%71`0`"#Q!2%P'425^CX(P```\-05NB?_/__@\0,:+Q!0`!H=$)``.B-_/__
M65E?7EO)PU6+[%&-1?Q0_W4(Z/O[__]9A<!9=![_%8!`0`"+`(M-_(T,B(M1
M!(U!!(72B1%TU(O(Z_#)PZ$8L$``@_C_=25H7$)``.BN^___A<!9=`^*`(3`
M=`D\,'0%:@%8ZP(SP*,8L$``PS/`PU6+[(/L(+C@0D``5XOX4(E%X,=%Y-A"
M0`#'1>C(0D``QT7LP$)``,=%\*Q"0`#'1?2H0D``B7WXZ#`C``"%P%D/AL0`
M``"-1>!35HE%_%?H._O__XOP687V#X2#````5N@((P``A<!9='C_=0A6_Q6$
M0$``687`675SZ#(B``!0Z$0B``#_-12P0`"+..C;(@``5HO8Z-,B``#_=0@#
MV.C)(@``@\00C40#`E#H`"(``%#H$B(``%G_,/\75HOX_S44L$``_W4(:)1!
M0`!7_Q640$``5_]U^.A`^___@\0DZPO_=0A7Z#+[__]968-%_`2+1?R+.%>)
M??CH;B(``(7`60^'1O___UY;7\G#58OLN."```#H72(``(-E]`!35KNH0D``
M:+!!0`#'1=AD0T``QT7<4$%``,=%X)Q!0`")7>3'1<#X04``QT7$7$-``,=%
MR%1#0`#'1<Q,0T``QT702$-``(E=U,=%Z$!#0`#'1>PT0T``B5WPZ!'Z__^+
M\%F%]G0?5NCB(0``A<!9=!16Z&K^__]6_Q5$0$``65GI<@4``+X`!```5XEU
M^.C_(```4.@1(0``BSA95NCP(```4.@"(0``6?\P_Q=968U-^%%0_Q4`0$``
MZ!_^__^%P(E%^'4^C7WHBS=6Z'TA``"%P%EV'U;HE/G__X7`670+4/\51$!`
M`%F)1?B#QP2#??@`=-2#??@`=0G'1?@L0T``ZT2+=?B`/@!T/+\'`0``H61`
M0`"#.`%^#P^^!E=0_Q5H0$``65GK$8L-;$!```^^!HL)9HL$02/'A<!U`\8&
M7T:`/@!UR8U%P(E%_(M%_(LP5NCU(```A<!9#X:@````5N@(^?__B_!9A?8/
MA($```#H&B```%#H)B```(LXZ`T@``!0Z!,@``!965!6Z/X?``!0Z`H@``!9
M_S#_5U"#Q`R%P'5-Z.8?``!0Z.P?``!FBT`&668E`/!F/0!`=3/HS!\``%#H
MV!\``(LX66H"5NB['P``4.C''P``6?\P_Q>#Q`R%P'4+5O\51$!``%F)1?2#
M1?P$@WWT``^$3/___X-]]``/A:D```"-1=B)1?R+1?R+,%;H,2```(7`60^&
MCP```.AG'P``4.AS'P``BSCH6A\``%#H8!\``%E94%;H2Q\``%#H5Q\``%G_
M,/]74(/$#(7`=4WH,Q\``%#H.1\``&:+0`999B4`\&8]`$!U,^@9'P``4.@E
M'P``BSA9:@)6Z`@?``!0Z!0?``!9_S#_%X/$#(7`=0M6_Q5$0$``68E%](-%
M_`2#??0`#X1=_____W7XZ)$?``#_=?2+^.B''P``OB1#0``#^%;H>A\``%,#
M^.AR'P``C;P'``0``.BJ'@``4.B\'@``BQ"#Q!2)5?Q7Z)8>``!0Z*@>``!9
M_S"+1?S_$/]U^(E%_%:+-91`0`#_-1"P0`#_=?1H&$-``%#_UO]U_/\5<$!`
M`&C`0D``Z#7W__]0_Q5$0$``BWT(4/\WZ&7U__^#Q#2)10B%P'4%BP>)10CH
M3?O__X7`#X4I`@``Z"0>``!0Z#`>``"+.,<$)`"```#_=0CH#1X``%#H&1X`
M`%G_,/]7/(/$#(E%"(7`#X3S`0``Z.X=``!0Z/H=``!9BSAJ`FK_:N[_=0CH
MUQT``%#HXQT``%G_,/]7,.C&'0``4.C2'0``BSB#Q!B-A2!___]J!E#_=0CH
MJAT``%#HMAT``%G_,/]71(/$$("]('___P`/A;4```"`O2%___]##X6H````
M@+TB?___00^%FP```("](W___T,/A8X```"`O21___](#X6!````@+TE?___
M175XZ$P=``!0Z%@=``!9BSAJ`FK_:L;_=0CH-1T``%#H01T``%G_,/]7,.@D
M'0``4.@P'0``BSB#Q!B-A2!___]J*5#_=0CH"!T``%#H%!T``%G_,/]71(V%
M('___U-0_S40L$``_W7\:`A#0`#_=?S_UH/$*.DB`0``C84@____4.@V`0``
MZ,@<``!0Z-0<``!968LXC84@?___:`"```!0_W4(Z*H<``!0Z+8<``!9_S#_
M5T2#Q!"%P'XD4(V%('___U"-A2#___]0Z!X!``#H?AP``%#HBAP``(/$$.NS
MZ&X<``!0Z'H<``"+.%G_=0CH71P``%#H:1P``%G_,/]7$(V%(/___U"-1:Q0
MZ+L3``"-18"#Q!`S_XE%"`^V1#VL4&@`0T``_W4(_]:#10@"@\0,1X/_%'SC
MC46`4X!EJ`!0_S40L$``_W7\:`A#0`#K06B\04``:%Q"0`#H7?7__UE94^CI
M&P``4.@!'```BSCHW!L``%#H]!L``/\P_U=H@\0,4/\U$+!``/]U_&CP0D``
M_W7\_]:#Q!C_=?QHL$%``.@6]?___W7\Z/'X__^+1?R#Q`Q?7EO)PXM$)`0S
MR<<``2-%9\=`!(FKS>_'0`C^W+J8QT`,=E0R$,=`$/#ATL.)2!2)2!B)2%S#
M58OL4XM=$%:+=0A7BTX4C039.\%S`_]&&(E&%(O#P>@=`488BT9<A<!T-&I`
M7ROX._M^`HO[BT9<5_]U#(U$!AQ0Z!0<```!?0P!?ER#Q`PKWX-^7$!U2U;H
M2@```%F#^T!\+(O[P>\&B\?WV,'@!@/8:D"-1AS_=0Q0Z-L;``"#10Q`5N@>
M````@\003W7B4XU&'/]U#%#HOAL``(/$#(E>7%]>6UW#58OL@>Q4`0``BT4(
M4U97C5`<C;6L_O__QT4($````(L*@\($B_F+V8'G``#_`,'K$`O[B]F!XP#_
M``#!X1`+V<'O",'C"`O[B3Z#Q@3_30AUS6I`C96T_O__7HM*+#-*&#-*^#,*
M@\($B_D#R<'O'POY3HEZ-'7CBW@$BU`(BW`,BPB+WR/7]],CWHOQ"]J+T<'J
M&\'F!0O6BW`0`_,#UHNUK/[__XV4,IEY@EJ+]\'F'L'O`@OWB_GWUR-X"(EU
M["/QB]H+_HORP>L;P>8%"]Z+M;#^__\#]P/>BW`,C;PSF7F"6HOQB]F)??C!
MYA[!ZP(+\XO:]],C7>R)=?PC\@O>B[6T_O__B5T(B]_!ZQO!YP4+WXM]"`/W
MB_K!YQ[!Z@(#WHMP"`OZBU7XC;0SF7F"6HM=^/?2(U7\(]^)??2+_@O3B][!
M[QO!XP4+^XN=N/[__P/:`_N+5>R-G!>9>8):BWWXB]>)70C!XA[![P(+UXO^
M]]<C??2)5?@CU@OZB]/!ZAO!XP4+TXN=O/[__P/?BWW\`].-E#J9>8):B_[!
MYQ[![@(+_HMU"/?6(W7XB7WP(WT(B]K!XP4+]XOZP>\;"_N+G<#^__\#WHMU
M]`/[C9PWF7F"6HM]"(OWB5W\P>8>P>\""_>+^O?7(WWPB74((_(+_HOSP>X;
MP>,%"_.+G<3^__\#WXM]^`/SC;0^F7F"6HOZP><>P>H""_J+5?SWTB-5"(E]
M["-]_(O>P>,%"]>+_L'O&PO[BYW(_O__`]J+5?`#^XV<%YEY@EJ+??R+UXE=
M^,'B'L'O`@O7B_[WUR-][(E5_"/6"_J+T\'J&\'C!0O3BYW,_O__`]^+?0@#
MTXM=^(V4.IEY@EJ+_L'G'L'N`@O^BW7X]]8C=?PCWXE]](OZ"_.+VL'O&\'C
M!0O[BYW0_O__`]Z+=>P#^XV<-YEY@EJ+??B+]XE=",'F'L'O`@OWB_KWUR-]
M](EU^"/R"_Z+\\'N&\'C!0OSBYW4_O__`]^+??P#\XVT/IEY@EJ+^L'G'L'J
M`@OZBU4(]](C5?B)??`C?0B+WL'C!0O7B_[![QL+^XN=V/[__P/:BU7T`_N-
MG!>9>8):BWT(B]>)7?S!XA[![P(+UXO^]]<C??")50@CU@OZB]/!ZAO!XP4+
MTXN=W/[__P/?BWWX`].-E#J9>8):B_[!YQ[![@(+_HMU_/?6(W4(B7WL(WW\
MB]K!XP4+]XOZP>\;"_N+G>#^__\#WHMU\`/[C9PWF7F"6HM]_(OWB5WXP>8>
MP>\""_>+^O?7(WWLB77\(_(+_HOSP>X;P>,%"_.+G>3^__\#WXM]"`/SBUWX
MC;0^F7F"6HOZP><>P>H""_J+5?CWTB-5_(E]]"/?B_X+TXO>P>\;P>,%"_N+
MG>C^__\#VHM5[`/[C9P7F7F"6HM]^(O7B5T(P>(>P>\""]>+_O?7(WWTB57X
M(]8+^HO3P>H;P>,%"].+G>S^__\#WXM]_`/3C90ZF7F"6HO^P><>P>X""_Z+
M=0CWUB-U^(E]\"-]"(O:P>,%"_>+^L'O&PO[BYWP_O__`]Z+=?0#^XV<-YEY
M@EJ+?0B+]XE=_,'F'L'O`@OWB_KWUR-]\(EU""/R"_Z+\\'N&\'C!0OSBYWT
M_O__`]^+??@#\XVT/IEY@EJ+^L'G'L'J`@OZBU7\]](C50B)?>PC??P+UXO^
MP>\;B][!XP4+^XN=^/[__P/:BU7P`_N-G!>9>8):BWW\B]>)7?C!XA[![P(+
MUXO[P>\;P>,%"_N+7>R)5?PSVHN5_/[__S/>`]>+_@/:BU4(P><>P>X""_Z-
ME!.AZ]ENB7WTB_*+^HN=`/___\'N&\'G!0OWBWWX,WW\`]Z+=>PS??0#^XV<
M-Z'KV6Z+??B+]XE=",'F'L'O`@OWB_O![QO!XP6)=?@+^XN=!/___S/R,W7T
M`]^+??P#\XVT/J'KV6Z+^L'G'L'J`@OZB]:+WHE]\,'J&\'C!0O3BUWX,]^+
MO0C___\S70@#^HM5]`/?C9P3H>O9;HM]"(E=_(O7P>(>P>\""]>+^\'O&\'C
M!0O[BUWPB54(,]J+E0S___\SW@/7B_X#VHM5^,'G'L'N`HV4$Z'KV6X+_HOR
MB]K![AO!XP4+\XM="(E][#/?B[T0____,UW\`_Z+=?`#WXM]_(V<,Z'KV6Z+
M]\'F'L'O`@OWB_N)7?B)=?S![QO!XP4+^XM=[#/>B[44____,]H#]XOZ`]Z+
M=0C!YQ[!Z@(+^HVT,Z'KV6Z)??2+UHO^BYT8____P>H;P><%"]>+??@S??P#
MVHM5[#-]]`/[C9P7H>O9;HM]^(O7B5T(P>(>P>\""]>)5?B+^S/6,U7TP>\;
MP>,%"_N+G1S___\#WXM]_`/3C90ZH>O9;HO^P><>P>X""_Z+\HO:B7WPP>X;
MP>,%"_.+7?@SWXN](/___S-="`/^BW7T`]^+?0B-G#.AZ]ENB_?!YA[![P(+
M]XO[B5W\B74(P>\;P>,%"_N+7?`SWHNU)/___S/:`_<#WHMU^(OZP><>P>H"
MC;0SH>O9;@OZB]:+WL'J&\'C!0O3BUT(B7WL,]^+O2C___\S7?P#^HM5\`/?
MBWW\C9P3H>O9;HO7P>(>P>\""]>+^XE=^(E5_,'O&\'C!0O[BUWL,]J+E2S_
M__\SW@/7B_X#VHM5",'G'L'N`@O^C903H>O9;HE]](ORB_J+G3#____![AO!
MYP4+]XM]^#-]_`/>BW7L,WWT`_N-G#>AZ]ENBWWXB_>)70C!YA[![P(+]XO[
MP>\;P>,%B77X"_N+G33___\S\C-U]`/?BWW\`_.-M#ZAZ]ENB_K!YQ[!Z@(+
M^HO6B]Z)??#!ZAO!XP4+TXM=^#/?B[TX____,UT(`_J+5?0#WXM]"(V<$Z'K
MV6Z+U\'B'L'O`@O7B_N)7?R)50C![QO!XP4+^XM=\#/:BY4\____,]X#UP/:
MBU7XC;P3H>O9;HO6P>(>P>X""]:+]XO?P>X;P>,%"_.+70B)5>PSVHN50/__
M_S-=_`/6BW7\`]J+5?"-G!.AZ]ENB];!XA[![@(+UHOSB5WXB57\P>X;P>,%
M"_.+7>PSVHN51/___S/?`]:+]P/:BU4(P>8>P>\""_>-E!.AZ]ENB77TB_*+
M^HN=2/___\'N&\'G!0OWBWWX,WW\`]Z+=>PS??0#^XVT-Z'KV6Z+??B)=0B+
M]\'F'L'O`@OWB_H+??2+70B)=?@C_HOR(W7TP>,%"_Z+=0C![AL+\XN=3/__
M_P/?BWW\`_.-M#[<O!N/B_K!YQ[!Z@(+^HO7B7WP"U4((U7X(WT(B]X+UXO^
MP>\;P>,%"_N+G5#___\#VHM5]`/[C9P7W+P;CXM]"(O7B5W\P>(>P>\""]>+
M^HE5"`O^(]8C??`+^HO3P>H;P>,%"].+G53___\#WXM]^`/3C90ZW+P;CXO^
MP><>P>X""_Z+VHOWB7WL"W7\(WW\P>,%(W4("_>+^L'O&PO[BYU8____`]Z+
M=?`#^XV<-]R\&X^+??R+]XE=^,'F'L'O`@OWB_Z)=?P+^B/R(WWL"_Z+\\'N
M&\'C!0OSBYU<____`]^+?0@#\XVT/MR\&X^+^L'G'L'J`@OZBU7\B7WTBUW\
M"]<C5?@CWXO^"].+WL'O&\'C!0O[BYU@____`]J+5>P#^XV4%]R\&X^+??B)
M50B+U\'B'L'O`@O7B_X+??2+70B)5?@C^HO6(U7TP>,%"_J+50C!ZAL+TXN=
M9/___P/?BWW\`].-E#K<O!N/B_[!YQ[![@(+_HO:B_>)??`+=0@C?0C!XP4C
M=?@+]XOZP>\;"_N+G6C___\#WHMU]`/[C9PWW+P;CXM]"(OWB5W\P>8>P>\"
M"_>+_HEU"`OZ(_(C??`+_HOSP>X;P>,%"_.+G6S___\#WXM]^`/SC;0^W+P;
MCXOZP><>P>H""_J+WHO7B7WL"U7\(WW\P>,%(U4("]>+_L'O&PO[BYUP____
M`]J+5?`#^XV<%]R\&X^+??R+UXE=^,'B'L'O`@O7B_J)5?P+_B/6(WWL"_J+
MT\'J&\'C!0O3BYUT____`]^+?0@#TXM=_(V4.MR\&X^+_L'G'L'N`@O^BW7\
M"_<CWR-U^(E]](OZ"_.+VL'O&\'C!0O[BYUX____`]Z+=>P#^XVT-]R\&X^+
M??B)=0B+]\'F'L'O`@OWB_H+??2+70B)=?@C_HOR(W7TP>,%"_Z+=0C![AL+
M\XN=?/___P/?`_.+??R-M#[<O!N/B_K!YQ[!Z@(+^HO>B]>)??`+50@C?0C!
MXP4C5?@+UXO^P>\;"_N+78`#VHM5]`/[C9P7W+P;CXM]"(O7B5W\P>(>P>\"
M"]>+^HE5"`O^(]8C??`+^HO3P>H;P>,%"].+780#WXM]^`/3C90ZW+P;CXO^
MP><>P>X""_Z+VHOWB7WL"W7\(WW\P>,%(W4("_>+^L'O&PO[BUV(`]Z+=?`#
M^XV<-]R\&X^+??R+]XE=^,'F'L'O`@OWB_Z)=?P+^B/R(WWL"_Z+\\'N&\'C
M!0OSBUV,`]^+?0@#\XM=_(VT/MR\&X^+^L'G'L'J`@OZBU7\"]<CWR-5^(E]
M](O^"].+WL'O&\'C!0O[BUV0`]J+5>P#^XV4%]R\&X^+??B)50B+U\'B'L'O
M`@O7B_X+??2+70B)5?@C^HO6(U7TP>,%"_J+50C!ZAL+TXM=E`/?BWW\`].-
ME#K<O!N/B_[!YQ[![@(+_HO:B_>)??`+=0@C?0C!XP4C=?@+]XOZP>\;"_N+
M79@#WHMU]`/[C9PWW+P;CXM]"(OWB5W\P>8>P>\""_>+^\'O&\'C!0O[BUWP
M,]Z)=0@SVHMUG`/WB_H#WHMU^,'G'L'J`HVT,];!8LH+^HO6B][!ZAO!XP4+
MTXM="#/?B7WLBWV@,UW\`_J+5?`#WXM]_(V<$];!8LJ+U\'B'L'O`@O7B_N)
M7?B)5?S![QO!XP4+^XM=[#/:BU6D,]X#UXO^`]J+50C!YQ[![@(+_HV4$];!
M8LJ)??2+\HOZBUVHP>X;P><%"_>+??@S??P#WHMU[#-]]`/[C9PWUL%BRHM]
M^(OWB5T(P>8>P>\""_>+^\'O&\'C!8EU^`O[BUVL,_(S=?0#WXM]_`/SC;0^
MUL%BRHOZP><>P>H""_J+UHO>B7WPP>H;P>,%"].+7?@SWXM]L#-="`/ZBU7T
M`]^+?0B-G!/6P6+*B]?!XA[![P(+UXO[B5W\B54(P>\;P>,%"_N+7?`SVHM5
MM#/>`]<#VHM5^(O^P><>P>X"C903UL%BR@O^B_*+VL'N&\'C!0OSBUT(B7WL
M,]^+?;@S7?P#_HMU\`/?BWW\C9PSUL%BRHOWP>8>P>\""_>+^XE=^(EU_,'O
M&\'C!0O[BUWL,]Z+=;PSV@/WB_H#WHMU",'G'L'J`@OZC;0SUL%BRHE]](O6
MB_[!ZAO!YP4+UXM]^(M=P#-]_`/:BU7L,WWT`_N-G!?6P6+*BWWXB]>)70C!
MXA[![P(+UXO[P>\;P>,%B57X"_N+7<0SUC-5]`/?BWW\`].-E#K6P6+*B_[!
MYQ[![@(+_HORB]J)??#![AO!XP4+\XM=^#/?BWW(,UT(`_Z+=?0#WXM]"(V<
M,];!8LJ+]\'F'L'O`@OWB_N)7?R)=0C![QO!XP4+^XM=\#/>BW7,,]H#]P/>
MBW7XB_K!YQ[!Z@*-M#/6P6+*"_J+UHO>P>H;P>,%"].+70B)?>PSWXM]T#-=
M_`/ZBU7P`]^-G!/6P6+*BWW\B5WXB]?!XA[![P(+UXO[P>\;P>,%"_N+7>R)
M5?PSVHM5U#/>`]>+_@/:BU4(P><>P>X""_Z-E!/6P6+*B7WTB_*+^HM=V,'N
M&\'G!0OWBWWX,WW\`]Z+=>PS??0#^XV<-];!8LJ+??B+]XE=",'F'L'O`@OW
MB_O![QO!XP6)=?@+^XM=W#/R,W7T`]^+??P#\XVT/M;!8LJ+^L'G'L'J`@OZ
MB]:+WHE]\,'J&\'C!0O3BUWX,]^+?>`S70@#^HM5]`/?BWT(C9P3UL%BRHO7
MP>(>P>\""]>)7?R)50B+^\'O&\'C!0O[BUWP,]J+5>0SW@/7`]J+5?B+_L'G
M'L'N`HV4$];!8LJ+70@+_HORB57T,]_![AO!X@4+\HM5_#/:`\X#V8M-\`-=
MZ(MU](V,"];!8LJ)"(M(!`/.B4@$B\K!X1[!Z@(+RHM5"`-("(E("(M(#`//
M7XE(#(M($`/*7HE($%O)PU6+[%-6BW4,BT88BUX4B44,B\/!Z`.#X#_&1#`<
M@$"#^#A^*FI`62O(C40P'%%J`%#H3`D``%;HC>W__VHXC48<:@!0Z#D)``"#
MQ!SK%6HX62O(C40P'%%J`%#H(@D``(/$#(M%#%:+R(A&5\'I&(A.5(O(P>D0
MB$Y5B\B+P_]U",'H&(A&6(O#P>@0B$99B\/!Z0C!Z`B(3E:(1EJ(7EOH!@``
M`%E97EM=PU:+="0,5N@3[?__BT0D#%F+#L'I&(@(BP[!Z1"(2`&+#L'I"(A(
M`HH.B$@#BU8$C4X$P>H8B%`$BQ'!ZA"(4`6+$<'J"(A0!HH)B$@'BU8(C4X(
MP>H8B%`(BQ'!ZA"(4`F+$<'J"(A0"HH)B$@+BU8,C4X,P>H8B%`,BQ'!ZA"(
M4`V+$<'J"(A0#HH)B$@/BU80C4X07L'J&(A0$(L1P>H0B%`1BQ'!Z@B(4!**
M"8A($\.!["0!``!3BYPD+`$``%97A=L/A#$"``!3Z,<'``"%P%D/A"("``!3
MZ+@'``"+\('&`@$``.CO!@``4.@!!P``BSA965;HWP8``%#H\08``%G_,/\7
MBSV40$``B_!3:(!#0`!6_]>-1"0L4%;_%4A`0`"#Q!R#^/^)1"04#X3'`0``
M58LMA$!``(U$)#!H4$%``%#_U5F%P%F-1"0P4'4.4VAX0T``5O_7@\00ZPMH
M=$-``%;_UX/$#+MP0T``4U;_U8OX687_670>4U?H#@<``%F%P%ET+&AL0T``
M5^C]!@``687`670;]D0D'!!T7(.\)#P!````=%)J`5;H__[__UE9C40D'%#_
M="0<_Q5,0$``687`60^%$P$``(U$)#!H4$%``%#_U5F%P%F-1"0P4'5;_[0D
M/`$``&AX0T``5O\5E$!``(/$$.M2C40D,%#_%0A`0`"#9"00`(L]4$!``(E$
M)!16_]>%P%ETEHM$)!#_1"00@_@*?8F#?"04`'0*_W0D%/\5#$!``%;KV&AT
M0T``5O\5E$!``(/$#%-6_]6+^%F%_UET)E-7Z"\&``!9A<!9#X1)____:&Q#
M0`!7Z!H&``!9A<!9#X0T____]D0D'!!T#H.\)#P!````#X45____C40D,%#_
M%0A`0`"#9"00`(L]4$!``(E$)!16_]>%P%D/A/G^__^+1"00_T0D$(/X"@^-
MZ/[__X-\)!0`=`K_="04_Q4,0$``5NO0_W0D&/\5H$!``/^T)#P!``#_%5A`
M0`!965U?7EN!Q"0!``##4U:+="0,5U;H_M___XOX5^C,W___68O86>C4X?__
MA<!T-(7V=#!6Z&8%``"%P%ET)6@D0T``4_\5A$!``%D[PUEU$VH!5NAB_?__
M:@!7Z%K]__^#Q!!?7EO#48-D)```4U97Z&X$``!0Z,($``!J`5N(&,<$)'1"
M0`#H-=W__X7`670+@#@Q=0:`>`$`=`7H_=___VH+4VCL0T``Z#4$``!0Z(,$
M``"#Q!"%P`^$GP```(M`##D=/+1``%6+\XMX&'YBO0`$``"-1O]J`%!7Z`($
M``!0Z$H$``"#Q!"%P'1$BP"+2`@CS3O-=06+0`SK$VH":@!0Z-L#``!0Z!T$
M``"#Q!!0H4"T0`#_-+#H>@0``%F%P%EU#?]$)!!&.S4\M$``?*.A/+1``%V-
M2/\Y3"0,=1T[PXOS?A=7Z)8#``!0Z-(#``!&63LU/+1``%E\Z6H%4VCH0T``
MZ'@#``!0Z,8#``"+\(/$$(7V=#&+1@QHW$-``/\PZ%H#``!0Z)`#``"+1@R#
MQ`R+`/9`"D!T#E#H0`,``%#H<`,``%E9:@53:-A#0`#H*P,``%#H>0,``(OP
M@\00A?9T;FB@04``Z/#;__^%P%ET`U#K2>A1X/__B_B%_W0WBT8,5_\PZ/0"
M``!0Z"H#``#HZ0(``%#H^P(``(LP@\005^C8`@``4.CJ`@``6?\P_U8(65GK
M&J%`M$``_S"+1@S_,.BW`@``4.CM`@``@\0,Z*D"``!0Z/T"``"`(`#HFP(`
M`%#HQ0(``(,@`&BP04``Z&;;__^#Q`RC.+!``(7`=1'_-4"T0`#HS>#__UFC
M.+!``.AF`@``4.B*`@``BS#'!"3M`0``_S4XL$``Z$P"``!0Z'`"``!9_S#_
M%H/$#(7`7UY;="6#^!%T((/X_W0;4*%`M$``_S4XL$``_S!HB$-``.@Y`@``
M@\006<-5B^Q148U%$%90C44,4(U%"%#HFP(``&H`Z(X"``"#Q!"`.`!U3.A[
M`@``A<"C-+!``'4CZ-<!``!0Z.\!``"+,%EJ`>C'`0``4.C?`0``6?\P_U8(
M65G_-32P0`#H/@(``.BI`0``4.@M`@``@"``65GHF0$``%#H%P(``(`(`NB+
M`0``4.@)`@``@`@!BT4(@V7\`(/`!8E%^%G?;?A9W!T`1$``W^">=@S_-<1`
M0`#H?@$``%F+10B-!(44````4.C'`0``6:-`M$``BTT,:@&+"8D(H4"T0`#'
M0`3X0T``H4"T0`#'0`@@1$``H4"T0`#'!3RT0``#````QT`,]$-``/\%/+1`
M`%@Y10A^'HL-/+1``(M5#(LU0+1```/(BQ2"0(E4COP[10A\XJ$\M$``BTT(
M`\&+#4"T0`!J`(-D@?P`BT4(BPT\M$``_S5`M$``C40!_U!HX#A``/\U-+!`
M`.@?`0``B_"#Q!2%]G4._S4TL$``Z`4!``!9B_#_-32P0`#H\0```,<$)&A"
M0`#H5]G__X7`674DH3BP0`"%P'44:+!!0`#H/]G__X7`6:,XL$``=`=0Z'O[
M__]9_S4TL$``Z*L```!9Z)\```"+QE[)P^@U````4.@5U___6;BH0D``:@!0
M4&B>-$``:`A$0`#H%@```%#HN````(/$&,/_)21!0`#_)2!!0`#_)1Q!0`#_
M)1A!0`#_)11!0`#_)1!!0`#_)0Q!0`#_)0A!0`#_)01!0`#_)0!!0`#_)?Q`
M0`#_)?A`0`#_)?1`0`#_)?!`0`#_)>Q`0`#_)>A`0`#_)>1`0`#_)>!`0`#_
M)=Q`0`#_)=A`0`#_)=1`0`#_)=!`0`#_)<Q`0`#_)<A`0`#_)<!`0`#_);Q`
M0`#_);A`0`#_);1`0`#_);!`0`#_):Q`0`#_):A`0`#,S,S,S,S,S/\ED$!`
M`/\EB$!``,S,S,Q1/0`0``"-3"0(<A2!Z0`0```M`!```(4!/0`0``!S["O(
MB\2%`8OABPB+0`10P\S_)6!`0`#_)5Q`0`#,S,S,58OL:O]HN)]``&A0.T``
M9*$`````4&2))0````"#["!35E>)9>B#9?P`:@'_%51`0`!9@PU8M$``_X,-
M7+1``/__%1A`0`"+#52T0`")"/\5'$!``(L-4+1``(D(H2!`0`"+`*-@M$``
MZ,````"#/3"P0```=0QH9A9``/\5)$!``%GHE````&@,L$``:`BP0`#H?P``
M`*%,M$``B478C4784/\U2+1``(U%X%"-1=10C47D4/\5+$!``&@$L$``:`"P
M0`#H3````/\5,$!``(M-X(D(_W7@_W74_W7DZ`?\__^#Q#")1=Q0_Q4T0$``
MBT7LBPB+"8E-T%!1Z`\```!96<.+9>C_==#_%3Q`0`#_)3A`0`#_)2A`0`!H
M```#`&@```$`Z`L```!96</#S/\EF$!``/\EG$!`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````.BC````````QJ,``+BC``"BHP```````(:E``!VI0``9J4``%*E``!&
MI0``-J4``":E```>I0``$*4```BE``#PI```YJ0``-BD``#,I```PJ0``)2E
M``"JI```H*0``):D``"&I```>J0``'"D``!FI```7*0``%*D``!(I```.*0`
M`"ZD```DI```&J0``!"D```&I```IJ4``+JE``"TI````````(*C``!PHP``
M6J,``$RC```ZHP``&J,```*C``#PH@``VJ(``,RB``#`H@``L*(``*2B``"4
MH@``@*(``&ZB``!>H@``2J(``#JB```JH@``'*(```BB``#XH0``X*$``,ZA
M``"^H0``KJ$``)JA``"(H0``=*$``&:A``!4H0``````````````````'BTK
M2``````"````00``````````X```.P```%P```!7:6XS,D-/4D4Z.F)O;W1S
M=')A<`````!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`<&5R;'AS:2YC
M````)7,E<R5S```N````4$%27U!23T=.04U%`````%!!4E]414U0`````#$`
M``!005)?0TQ%04X]``!#3$5!3@```%!!4E]'3$]"04Q?0TQ%04X`````4$%2
M7T=,3T)!3%]414U0`%!!4E]435!$25(``%!!4E]'3$]"04Q?5$U01$E2````
M4$%27T=,3T)!3%]$14)51P````!005)?05)'5E\P``!005)?05)'0P````!0
M05)?0T%#2$4```!005)?1$5"54<```!005)?0TQ%04X```!005)?4U!!5TY%
M1`!005)?24Y)5$E!3$E:140`7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@
M("`@("```````````$193$1?3$E"4D%265]0051(````4$%42`````!,24)2
M05)97U!!5$@`````3$E"4$%42`!,1%],24)205)97U!!5$@`)7,E<W1E;7`M
M)74E<P```"4P,G@`````)7,E<V-A8VAE+25S)7,``"5S)7,E<R5S`````'!A
M<BT`````4UE35$5-``!54T523D%-10````!54T52`````%1-4`!414U0````
M`%1%35!$25(`5$U01$E2``!#.EQ414U0`%PN+@!<+@``)7,``"5S7"5S````
M)7-<*BXJ```E<SH@8W)E871I;VX@;V8@<')I=F%T92!T96UP;W)A<GD@<W5B
M9&ER96-T;W)Y("5S(&9A:6QE9"`M(&%B;W)T:6YG('=I=&@@)6DN"@```#``
M``!P97)L+F5X90`````8````05)'5@`````M+0``+64``````````(#____/
M04EN=&5R;F%L<SHZ4$%2.CI"3T]4`````",A+W5S<B]B:6XO<&5R;`H*979A
M;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"B`@("!I
M9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*"G!A8VMA9V4@
M7U]P87)?<&P["@HC("TM+2!4:&ES('-C<FEP="!M=7-T(&YO="!U<V4@86YY
M(&UO9'5L97,@870@8V]M<&EL92!T:6UE("TM+0HC('5S92!S=')I8W0["@HC
M;&EN92`Q-3D*"FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I
M.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["B`@("!R97%U:7)E($9I
M;&4Z.E1E;7`["B`@("!R97%U:7)E($9I;&4Z.D)A<V5N86UE.PH@("`@<F5Q
M=6ER92!&:6QE.CI3<&5C.PH@("`@;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N
M86UE.CID:7)N86UE*"1P87)?=&5M<"D["B`@("!O=71S*'%Q>U)E;6]V:6YG
M(&9I;&5S(&EN("(D<&%R7W1E;7`B?2D["B`@("!&:6QE.CI&:6YD.CIF:6YD
M9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T
M96UP*3L*("`@(')M9&ER("1P87)?=&5M<#L*("`@(')M9&ER("1T;W!D:7([
M"@H@("`@:68@*"UD("1P87)?=&5M<"D@>PH@("`@("`@(",@4V]M971H:6YG
M('=E;G0@=W)O;F<@=6YL:6YK:6YG('1H92!T96UP;W)A<GD@9&ER96-T;W)Y
M+B`@5&AI<PH@("`@("`@(",@='EP:6-A;&QY(&AA<'!E;G,@;VX@<&QA=&9O
M<FUS('1H870@9&ES86QL;W<@=6YL:6YK:6YG('-H87)E9`H@("`@("`@(",@
M;&EB<F%R:65S(&%N9"!E>&5C=71A8FQE<R!T:&%T(&%R92!I;B!U<V4N(%5N
M;&EN:R!W:71H(&$@8F%C:V=R;W5N9`H@("`@("`@(",@<VAE;&P@8V]M;6%N
M9"!S;R!T:&4@9FEL97,@87)E(&YO(&QO;F=E<B!I;B!U<V4@8GD@=&AI<R!P
M<F]C97-S+@H*("`@("`@("!M>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"B`@
M("`@("`@("`@(%1%35!,051%(#T^("=T;7!86%A86"<L"B`@("`@("`@("`@
M($1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*("`@
M("`@("`@("`@4U5&1DE8(#T^("<N8VUD)RP*("`@("`@("`@("`@54Y,24Y+
M(#T^(#`L"B`@("`@("`@*3L*"B`@("`@("`@(R!"96-A=7-E('1H92!P87)?
M=&5M<"!D:7)E8W1O<GD@:7,@9V]I;F<@=&\@8F4@9&5L971E9"!I;B!A"B`@
M("`@("`@(R!B86-K9W)O=6YD('!R;V-E<W,L('1H92!P87)E;G0@<')O8V5S
M<R!I9"!M87D@8F4@<F5U<V5D(&)E9F]R92!T:&4*("`@("`@("`C(&)A8VMG
M<F]U;F0@<')O8V5S<R!C;VUP;&5T97,N("!4;R!E;G-U<F4@=&AA="!T:&4@
M=&5M<&]R87)Y"B`@("`@("`@(R!D:7)E8W1O<GD@9&]E<R!N;W0@9V5T(')E
M=7-E9"!W:&EL92!I="!I<R!B96EN9R!D96QE=&5D+"!T<GD@=&\*("`@("`@
M("`C(')E;F%M92!I="!T;R!A(&YA;64@=&AA="!I<R!R96QA=&5D('1O('1H
M92!T96UP;W)A<GD@<V-R:7!T(&9I;&4N"@HC($9)6$U%.B!4:&ES(&)R96%K
M<R!T:')E861E9"!A<'!L:6-A=&EO;G,N($$@9FEX(&ES(&EN('1H92!W;W)K
M<RP@8G5T(&UA>0HC("`@("`@("!S=&EL;"!T86ME(&$@=VAI;&4N(%1H92!F
M:7@@=V]U;&0@8F4@=&\@;6%K92!S=7)E('1H870@=&AI<R!I<R!O;FQY"B,@
M("`@("`@(')U;B!I;B!T:&4@3$%35"!214U!24Y)3D<@=&AR96%D+@H@("`@
M("`@(`HC("`@("`@("!M>2`D=&UP;F%M92`]("A&:6QE.CI3<&5C+3YS<&QI
M='!A=&@H)'1M<"T^9FEL96YA;64I*5LR73L@(R!F:6QE;F%M90HC("`@("`@
M("`D=&UP;F%M92`]?B!S+UPN6UXN72HD+RYD:7(O.PHC("`@("`@("!M>2`D
M;F5W1&ER(#T@1FEL93HZ4W!E8RT^8V%T<&%T:"@*(R`@("`@("`@("`@("A&
M:6QE.CI3<&5C+3YS<&QI='!A=&@H)'!A<E]T96UP*2E;,"XN,5TL("1T;7!N
M86UE*3L*(R`@("`@("`@:68@*')E;F%M92`D<&%R7W1E;7`L("1N97=$:7(I
M('L*(R`@("`@("`@("`@(&]U=',H(E)E;F%M960@)'!A<E]T96UP('1O("1N
M97=$:7(B*3L*(R`@("`@("`@("`@("1P87)?=&5M<"`]("1N97=$:7(["B,@
M("`@("`@('T*"B`@("`@("`@:68@*"1>3R`]?B!M+W=I;C,R+VDI('L*("`@
M("`@("`@("`@<')I;G0@)'1M<"`B"CIL;V]P"G)M9&ER("]Q("]S(%PB)'!A
M<E]T96UP7"(*:68@97AI<W0@7"(D<&%R7W1E;7!<(B!G;W1O(&QO;W`*<FUD
M:7(@7"(D=&]P9&ER7"(*<FT@7"(B("X@)'1M<"T^9FEL96YA;64@+B`B7"(*
M(CL*("`@("`@("`@("`@8VQO<V4@)'1M<#L*("`@("`@("`@("`@;7D@)'!R
M;V,["B`@("`@("`@("`@(%=I;C,R.CI0<F]C97-S.CI#<F5A=&4H"B`@("`@
M("`@("`@("`@("`D<')O8RP@)$5.5GM#3TU34$5#?2P*("`@("`@("`@("`@
M("`@("(D14Y6>T-/35-014-]("]C(%PB(B`N("1T;7`M/F9I;&5N86UE("X@
M(EPB(#YN=6P@,CYN=6P@(BP*("`@("`@("`@("`@("`@(#$L($Y/4DU!3%]0
M4DE/4DE465]#3$%34RP@(BXB"B`@("`@("`@("`@("D["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@<')I;G0@)'1M<"`B(R$O8FEN+W-H"G=H:6QE
M(%L@+60@)R1P87)?=&5M<"<@73L@9&\*("`@<FT@+7)F("<D<&%R7W1E;7`G
M"F1O;F4*<FUD:7(@)R1T;W!D:7(G"G)M("<B("X@)'1M<"T^9FEL96YA;64@
M+B`B)PHB.PH@("`@("`@("`@("!C:&UO9"`P-S`P+"1T;7`M/F9I;&5N86UE
M.PH@("`@("`@("`@("!M>2`D8VUD(#T@)'1M<"T^9FEL96YA;64@+B`G(#XO
M9&5V+VYU;&P@,CXF,2`F)SL*("`@("`@("`@("`@8VQO<V4@)'1M<#L*("`@
M("`@("`@("`@<WES=&5M*"1C;60I.PH@("`@("`@('T*("`@("`@("!O=71S
M*'%Q*%-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE
M86YU<"DI.PH@("`@?0I]('T*"D)%1TE.('L*("`@($EN=&5R;F%L<SHZ4$%2
M.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["@H@
M("`@979A;"!["@I?<&%R7VEN:71?96YV*"D["@II9B`H97AI<W1S("1%3E9[
M4$%27T%21U9?,'T@86YD("1%3E9[4$%27T%21U9?,'T@*2!["B`@("!`05)'
M5B`](&UA<"`D14Y6>R)005)?05)'5E\D7R)]+"`H,2`N+B`D14Y6>U!!4E]!
M4D=#?2`M(#$I.PH@("`@)#`@/2`D14Y6>U!!4E]!4D=67S!].PI]"F5L<V4@
M>PH@("`@9F]R("AK97ES("5%3E8I('L*("`@("`@("!D96QE=&4@)$5.5GLD
M7WT@:68@+UY005)?05)'5E\O.PH@("`@?0I]"@IM>2`D<75I970@/2`A)$5.
M5GM005)?1$5"54=].PH*(R!F:7@@)'!R;V=N86UE(&EF(&EN=F]K960@9G)O
M;2!0051("FUY("5#;VYF:6<@/2`H"B`@("!P871H7W-E<"`@("`]/B`H)%Y/
M(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*("`@(%]E>&4@("`@("`@(#T^
M("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G
M)RDL"B`@("!?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_
M("=<7"<@.B`G+R<I+`HI.PH*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T
M96UP*"D["@HC($UA9VEC('-T<FEN9R!C:&5C:VEN9R!A;F0@97AT<F%C=&EN
M9R!B=6YD;&5D(&UO9'5L97,@>WM["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P
M;W,I.PI["B`@("!L;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*"B`@
M("`C($-H96-K(&9I;&4@='EP92P@9V5T('-T87)T(&]F(&1A=&$@<V5C=&EO
M;B![>WL*("`@(&]P96X@7T9(+"`G/"<L("1P<F]G;F%M92!O<B!L87-T.PH@
M("`@8FEN;6]D92A?1D@I.PH*("`@(&UY("1B=68["B`@("!S965K(%]&2"P@
M+3@L(#(["B`@("!R96%D(%]&2"P@)&)U9BP@.#L*("`@(&QA<W0@=6YL97-S
M("1B=68@97$@(EQN4$%2+G!M7&XB.PH*("`@('-E96L@7T9(+"`M,3(L(#([
M"B`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@('-E96L@7T9(+"`M,3(@+2!U
M;G!A8VLH(DXB+"`D8G5F*2P@,CL*("`@(')E860@7T9(+"`D8G5F+"`T.PH*
M("`@("1D871A7W!O<R`]("AT96QL(%]&2"D@+2`T.PH@("`@(R!]?7T*"B`@
M("`C($5X=')A8W1I;F<@96%C:"!F:6QE(&EN=&\@;65M;W)Y('M[>PH@("`@
M;7D@)7)E<75I<F5?;&ES=#L*("`@('=H:6QE("@D8G5F(&5Q(")&24Q%(BD@
M>PH@("`@("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@("`@(')E860@7T9(
M+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*"B`@("`@("`@;7D@)&9U;&QN
M86UE(#T@)&)U9CL*("`@("`@("!O=71S*'%Q*%5N<&%C:VEN9R!F:6QE("(D
M9G5L;&YA;64B+BXN*2D["B`@("`@("`@;7D@)&-R8R`]("@@)&9U;&QN86UE
M(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*("`@("`@
M("!M>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H
M+BHI*%PN+BHI?"D["@H@("`@("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@
M("`@(')E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*"B`@("`@
M("`@:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\
M:7A\86PI)"]I*2!["B`@("`@("`@("`@(&UY("@D;W5T+"`D9FEL96YA;64I
M(#T@7W1E;7!F:6QE*"1E>'0L("1C<F,I.PH@("`@("`@("`@("!I9B`H)&]U
M="D@>PH@("`@("`@("`@("`@("`@8FEN;6]D92@D;W5T*3L*("`@("`@("`@
M("`@("`@('!R:6YT("1O=70@)&)U9CL*("`@("`@("`@("`@("`@(&-L;W-E
M("1O=70["B`@("`@("`@("`@("`@("!C:&UO9"`P-S4U+"`D9FEL96YA;64[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@)%!!4CHZ2&5A=GDZ.D9U;&Q#
M86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PH@("`@("`@("`@("`D4$%2
M.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["B`@
M("`@("`@?0H@("`@("`@(&5L<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL
M:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I('L*("`@("`@("`@
M("`@(R!S:&]U;&0@8F4@;6]V960@=&\@7W1E;7!F:6QE*"D*("`@("`@("`@
M("`@;7D@)&9I;&5N86UE(#T@(B1%3E9[4$%27U1%35!]+R1B87-E;F%M921E
M>'0B.PH@("`@("`@("`@("!O=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*
M("`@("`@("`@("`@;W!E;B!M>2`D;W5T+"`G/B<L("1F:6QE;F%M92!O<B!D
M:64@)"$["B`@("`@("`@("`@(&)I;FUO9&4H)&]U="D["B`@("`@("`@("`@
M('!R:6YT("1O=70@)&)U9CL*("`@("`@("`@("`@8VQO<V4@)&]U=#L*("`@
M("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@("1R97%U:7)E7VQI
M<W1[)&9U;&QN86UE?2`]"B`@("`@("`@("`@("1005(Z.DAE879Y.CI-;V1U
M;&5#86-H97LD9G5L;&YA;65](#T@>PH@("`@("`@("`@("`@("`@8G5F(#T^
M("1B=68L"B`@("`@("`@("`@("`@("!C<F,@/3X@)&-R8RP*("`@("`@("`@
M("`@("`@(&YA;64@/3X@)&9U;&QN86UE+`H@("`@("`@("`@("!].PH@("`@
M("`@('T*("`@("`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@('T*("`@(",@
M?7U]"@H@("`@;&]C86P@0$E.0R`]("AS=6(@>PH@("`@("`@(&UY("@D<V5L
M9BP@)&UO9'5L92D@/2!`7SL*"B`@("`@("`@<F5T=7)N(&EF(')E9B`D;6]D
M=6QE(&]R("$D;6]D=6QE.PH*("`@("`@("!M>2`D9FEL96YA;64@/2!D96QE
M=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!\?"!D;R!["B`@("`@("`@("`@
M(&UY("1K97D["B`@("`@("`@("`@(&9O<F5A8V@@*&ME>7,@)7)E<75I<F5?
M;&ES="D@>PH@("`@("`@("`@("`@("`@;F5X="!U;FQE<W,@+UQ1)&UO9'5L
M95Q%)"\["B`@("`@("`@("`@("`@("`D:V5Y(#T@)%\[(&QA<W0["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@9&5L971E("1R97%U:7)E7VQI<W1[)&ME
M>7T@:68@9&5F:6YE9"@D:V5Y*3L*("`@("`@("!](&]R(')E='5R;CL*"B`@
M("`@("`@)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1F:6QE;F%M92\D;6]D
M=6QE(CL*"B`@("`@("`@:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE
M9"@F24\Z.D9I;&4Z.FYE=RDI('L*("`@("`@("`@("`@;7D@)&9H(#T@24\Z
M.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*("`@("`@("`@("`@8FEN
M;6]D92@D9F@I.PH@("`@("`@("`@("!P<FEN="`D9F@@)&9I;&5N86UE+3Y[
M8G5F?3L*("`@("`@("`@("`@<V5E:R@D9F@L(#`L(#`I.PH@("`@("`@("`@
M("!R971U<FX@)&9H.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@
M("`@("`@;7D@*"1O=70L("1N86UE*2`](%]T96UP9FEL92@G+G!M)RP@)&9I
M;&5N86UE+3Y[8W)C?2D["B`@("`@("`@("`@(&EF("@D;W5T*2!["B`@("`@
M("`@("`@("`@("!B:6YM;V1E*"1O=70I.PH@("`@("`@("`@("`@("`@<')I
M;G0@)&]U="`D9FEL96YA;64M/GMB=69].PH@("`@("`@("`@("`@("`@8VQO
M<V4@)&]U=#L*("`@("`@("`@("`@?0H@("`@("`@("`@("!O<&5N(&UY("1F
M:"P@)SPG+"`D;F%M92!O<B!D:64@)"$["B`@("`@("`@("`@(&)I;FUO9&4H
M)&9H*3L*("`@("`@("`@("`@<F5T=7)N("1F:#L*("`@("`@("!]"@H@("`@
M("`@(&1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;FYO="!F:6YD("1M
M;V1U;&4A7&XB.PH@("`@?2P@0$E.0RD["@H@("`@(R!.;W<@;&]A9"!A;&P@
M8G5N9&QE9"!F:6QE<R![>WL*"B`@("`C(&EN:71I86QI>F4@<VAA<F5D(&]B
M:F5C="!P<F]C97-S:6YG"B`@("!R97%U:7)E(%A33&]A9&5R.PH@("`@<F5Q
M=6ER92!005(Z.DAE879Y.PH@("`@<F5Q=6ER92!#87)P.CI(96%V>3L*("`@
M(')E<75I<F4@17AP;W)T97(Z.DAE879Y.PH@("`@4$%2.CI(96%V>3HZ7VEN
M:71?9'EN86QO861E<B@I.PH*("`@(",@;F]W(&QE="=S('1R>2!G971T:6YG
M(&AE;'!E<B!M;V1U;&5S(&9R;VT@=VET:&EN"B`@("!R97%U:7)E($E/.CI&
M:6QE.PH*("`@(",@;&]A9"!R97-T(&]F('1H92!G<F]U<"!I;@H@("`@=VAI
M;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;
M,%TI('L*("`@("`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?
M7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH@("`@("`@('5N;&5S<R`H)$E.0WLD
M9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PH@("`@("`@
M("`@("`C(')E<75I<F4@;6]D=6QE<RP@9&\@;W1H97(@97AE8W5T86)L92!F
M:6QE<PH@("`@("`@("`@("!I9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI
M('L*("`@("`@("`@("`@("`@(')E<75I<F4@)&9I;&5N86UE.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@(R!3
M:VEP($%C=&EV95-T871E)W,@<VET96-U<W1O;6EZ92YP;"!F:6QE.@H@("`@
M("`@("`@("`@("`@9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@
M+W-I=&5C=7-T;VUI>F5<+G!L)"\["B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("`@("`@9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*("`@
M('T*"B`@("`C('U]?0H*("`@(&QA<W0@=6YL97-S("1B=68@97$@(E!+7#`P
M,UPP,#0B.PH@("`@)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.PI]"B,@
M?7U]"@HC($%R9W5M96YT('!R;V-E<W-I;F<@>WM["FUY($!P87)?87)G<SL*
M;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PH*)'%U
M:65T(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PH*(R!$;VXG="!S=V%L
M;&]W(&%R9W5M96YT<R!F;W(@8V]M<&EL960@97AE8W5T86)L97,@=VET:&]U
M="`M+7!A<BUO<'1I;VYS"FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@
M97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PH@("`@;7D@)61I<W1?
M8VUD(#T@<7<H"B`@("`@("`@<"`@(&)L:6)?=&]?<&%R"B`@("`@("`@:2`@
M(&EN<W1A;&Q?<&%R"B`@("`@("`@=2`@('5N:6YS=&%L;%]P87(*("`@("`@
M("!S("`@<VEG;E]P87(*("`@("`@("!V("`@=F5R:69Y7W!A<@H@("`@*3L*
M"B`@("!M>2!`861D7W1O7VEN8SL*("`@('=H:6QE("A`05)'5BD@>PH@("`@
M("`@("1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R
M(&QA<W0["@H@("`@("`@(&EF("@D,2!E<2`G22<I('L*("`@("`@("`@("`@
M<'5S:"!`861D7W1O7VEN8RP@)#(["B`@("`@("`@?0H@("`@("`@(&5L<VEF
M("@D,2!E<2`G32<I('L*("`@("`@("`@("`@979A;"`B=7-E("0R(CL*("`@
M("`@("!]"B`@("`@("`@96QS:68@*"0Q(&5Q("=!)RD@>PH@("`@("`@("`@
M("!U;G-H:69T($!P87)?87)G<RP@)#(["B`@("`@("`@?0H@("`@("`@(&5L
M<VEF("@D,2!E<2`G3R<I('L*("`@("`@("`@("`@)&]U="`]("0R.PH@("`@
M("`@('T*("`@("`@("!E;'-I9B`H)#$@97$@)V(G*2!["B`@("`@("`@("`@
M("1B=6YD;&4@/2`G<VET92<["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@D
M,2!E<2`G0B<I('L*("`@("`@("`@("`@)&)U;F1L92`]("=A;&PG.PH@("`@
M("`@('T*("`@("`@("!E;'-I9B`H)#$@97$@)W$G*2!["B`@("`@("`@("`@
M("1Q=6EE="`](#$["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@D,2!E<2`G
M3"<I('L*("`@("`@("`@("`@;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I
M92`B6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A(CL*("`@("`@("!]"B`@("`@
M("`@96QS:68@*"0Q(&5Q("=4)RD@>PH@("`@("`@("`@("`D8V%C:&5?;F%M
M92`]("0R.PH@("`@("`@('T*"B`@("`@("`@<VAI9G0H0$%21U8I.PH*("`@
M("`@("!I9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*("`@("`@("`@
M("`@9&5L971E("1%3E9[)U!!4E]414U0)WT["B`@("`@("`@("`@(&EN:71?
M:6YC*"D["B`@("`@("`@("`@(')E<75I<F4@4$%2.CI$:7-T.PH@("`@("`@
M("`@("`F>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*("`@
M("`@("`@("`@)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*
M("`@("`@("`@("`@97AI=#L*("`@("`@("!]"B`@("!]"@H@("`@=6YS:&EF
M="!`24Y#+"!`861D7W1O7VEN8SL*?0H*(R!86%@@+2T@861D("TM<&%R+61E
M8G5G('-U<'!O<G0A"@HC('U]?0H*(R!/=71P=70@;6]D92`H+4\I(&AA;F1L
M:6YG('M[>PII9B`H)&]U="D@>PH@("`@>PH@("`@("`@("-L;V-A;"`D24Y#
M>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<["B`@
M("`@("`@<F5Q=6ER92!)3SHZ1FEL93L*("`@("`@("!R97%U:7)E($%R8VAI
M=F4Z.EII<#L*("`@('T*"@H@("`@;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*
M("`@(&UY("1Z:7`["@H*("`@(&EF("AD969I;F5D("1P87(I('L*("`@("`@
M("!O<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@
M)R1P87(G.B`D(2(["B`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@(&)L
M97-S*"1F:"P@)TE/.CI&:6QE)RD["@H@("`@("`@("1Z:7`@/2!!<F-H:79E
M.CI::7`M/FYE=SL*("`@("`@("`H("1Z:7`M/G)E861&<F]M1FEL94AA;F1L
M92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"B`@("`@
M("`@("`@(&]R(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*("`@('T*
M"@H@("`@;7D@)65N=B`](&1O('L*("`@("`@("!I9B`H)'II<"!A;F0@;7D@
M)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PH@("`@("`@
M("`@("`D;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*("`@("`@("`@("`@)&UE
M=&$@/7X@<R]>7%,N*B\O;7,["B`@("`@("`@("`@("1M971A(#U^("]>("`H
M6UXZ72LI.B`H+BLI)"]M9SL*("`@("`@("!]"B`@("!].PH*("`@(",@3W!E
M;B!I;G!U="!A;F0@;W5T<'5T(&9I;&5S('M[>PH@("`@;&]C86P@)"\@/2!<
M-#L*"B`@("!I9B`H9&5F:6YE9"`D<&%R*2!["B`@("`@("`@;W!E;B!005(L
M("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*("`@("`@("!B:6YM;V1E
M*%!!4BD["B`@("`@("`@9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U
M;FQE<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B.PH@("`@?0H*("`@($-R96%T
M95!A=&@H)&]U="D@.PH@("`@"B`@("!M>2`D9F@@/2!)3SHZ1FEL92T^;F5W
M*`H@("`@("`@("1O=70L"B`@("`@("`@24\Z.D9I;&4Z.D]?0U)%050H*2!\
M($E/.CI&:6QE.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*
M("`@("`@("`P-S<W+`H@("`@*2!O<B!D:64@)"$["B`@("!B:6YM;V1E*"1F
M:"D["@H@("`@)"\@/2`H9&5F:6YE9"`D9&%T85]P;W,I(#\@7"1D871A7W!O
M<R`Z('5N9&5F.PH@("`@<V5E:R!?1D@L(#`L(#`["B`@("!M>2`D;&]A9&5R
M(#T@<V-A;&%R(#Q?1D@^.PH@("`@:68@*"$D14Y6>U!!4E]615)"051)37T@
M86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["B`@("`@("`@<F5Q
M=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["B`@("`@("`@4$%2.CI&:6QT
M97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD;&]A9&5R+"`D,"D*("`@('T*
M("`@(&9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5E;G8I('L*("`@("`@
M("!M>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PH@("`@("`@("1V86P@
M/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG(ETO.PH@("`@("`@(&UY("1M
M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*("`@("`@
M("!M>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PH@("`@
M("`@("1L;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*("`@("`@("`@("`@)&UA
M9VEC("X@)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T
M*2DI"B`@("`@("`@?65G.PH@("`@?0H@("`@)&9H+3YP<FEN="@D;&]A9&5R
M*3L*("`@("0O(#T@=6YD968["B`@("`C('U]?0H*("`@(",@5W)I=&4@8G5N
M9&QE9"!M;V1U;&5S('M[>PH@("`@:68@*"1B=6YD;&4I('L*("`@("`@("!R
M97%U:7)E(%!!4CHZ2&5A=GD["B`@("`@("`@4$%2.CI(96%V>3HZ7VEN:71?
M9'EN86QO861E<B@I.PH@("`@("`@(&EN:71?:6YC*"D["B`@("`@("`@<F5Q
M=6ER95]M;V1U;&5S*"D["@H@("`@("`@(&UY($!I;F,@/2!S;W)T('L*("`@
M("`@("`@("`@;&5N9W1H*"1B*2`\/3X@;&5N9W1H*"1A*0H@("`@("`@('T@
M9W)E<"!["B`@("`@("`@("`@("$O0E-$4$%.+PH@("`@("`@('T@9W)E<"![
M"B`@("`@("`@("`@("@D8G5N9&QE(&YE("=S:71E)RD@;W(*("`@("`@("`@
M("`@*"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*("`@
M("`@("`@("`@("1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D[
M"B`@("`@("`@?2!`24Y#.PH*("`@("`@("!I9B`H)$-O;F9I9WM?9&5L:6U]
M(&5Q("=<7"<I('L@<WM<7'U[+WUG(&9O<B!`:6YC('T*"B`@("`@("`@;7D@
M)69I;&5S.PH@("`@("`@("]>7SPH+BLI)"\@86YD("1F:6QE<WLD,7TK*R!F
M;W(@:V5Y<R`E.CH["B`@("`@("`@)&9I;&5S>R1??2LK(&9O<B!V86QU97,@
M)4E.0SL*"B`@("`@("`@;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[
M;&EB7V5X='T["B`@("`@("`@;7D@)7=R:71T96X["@H@("`@("`@(&9O<F5A
M8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*("`@("`@("`@("`@;7D@*"1N86UE
M+"`D9FEL92D["@H@("`@("`@("`@("!F;W)E86-H(&UY("1D:7(@*$!I;F,I
M('L*("`@("`@("`@("`@("`@(&EF("@D;F%M92`]("1005(Z.DAE879Y.CI&
M=6QL0V%C:&5[)%]]*2!["B`@("`@("`@("`@("`@("`@("`@)&9I;&4@/2`D
M7SL*("`@("`@("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C
M72DI7%HO:2D@>PH@("`@("`@("`@("`@("`@("`@("@D9FEL92P@)&YA;64I
M(#T@*"0Q+"`D,BD["B`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@(&5L<VEF("AM(5XO;&]A9&5R
M+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PH@("`@("`@("`@("`@("`@("`@(&EF
M("AM>2`D<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R0Q?2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`H)&9I;&4L("1N86UE*2`]("@D<F5F
M+"`D,2D["B`@("`@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&5L<VEF("@M9B`B
M)&1I<B\D,2(I('L*("`@("`@("`@("`@("`@("`@("`@("`@*"1F:6QE+"`D
M;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["B`@("`@("`@("`@("`@("`@("`@
M("`@(&QA<W0["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("!N97AT('5N;&5S<R!D
M969I;F5D("1N86UE(&%N9"!N;W0@)'=R:71T96Y[)&YA;65]*RL["B`@("`@
M("`@("`@(&YE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1
M)&QI8E]E>'1<120O.PH@("`@("`@("`@("!O=71S*"!J;VEN("(B+`H@("`@
M("`@("`@("`@("`@<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M
M/GMN86UE?2`Z("1F:6QE+`H@("`@("`@("`@("`@("`@<7$H(BXN+BD*("`@
M("`@("`@("`@*3L*"B`@("`@("`@("`@(&UY("1C;VYT96YT.PH@("`@("`@
M("`@("!I9B`H<F5F*"1F:6QE*2D@>PH@("`@("`@("`@("`@("`@)&-O;G1E
M;G0@/2`D9FEL92T^>V)U9GT["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M96QS92!["B`@("`@("`@("`@("`@("!O<&5N($9)3$4L("<\)RP@)&9I;&4@
M;W(@9&EE(")#86XG="!O<&5N("1F:6QE.B`D(2(["B`@("`@("`@("`@("`@
M("!B:6YM;V1E*$9)3$4I.PH@("`@("`@("`@("`@("`@)&-O;G1E;G0@/2`\
M1DE,13X["B`@("`@("`@("`@("`@("!C;&]S92!&24Q%.PH*("`@("`@("`@
M("`@("`@(%!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&-O
M;G1E;G0L("1F:6QE*0H@("`@("`@("`@("`@("`@("`@(&EF("$D14Y6>U!!
M4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*
M"B`@("`@("`@("`@("`@("`C($1O(&YO="!L970@6%-,;V%D97(@<&EC:R!U
M<"!A=71O+RH@9G)O;2!E;G9I<F]N;65N=`H@("`@("`@("`@("`@("`@)&-O
M;G1E;G0@/7X@<R]G;W1O("MR971R>2`K=6YL97-S("LN*B]G;W1O(')E=')Y
M.R\*("`@("`@("`@("`@("`@("`@("!I9B!L8R@D;F%M92D@97$@;&,H(EA3
M3&]A9&5R+G!M(BD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&]U=',H
M<7$H5W)I='1E;B!A<R`B)&YA;64B*2D["B`@("`@("`@("`@("1F:"T^<')I
M;G0H(D9)3$4B*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AP86-K*"=.)RP@
M;&5N9W1H*"1N86UE*2`K(#DI*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AS
M<')I;G1F*`H@("`@("`@("`@("`@("`@(B4P.'@O)7,B+"!!<F-H:79E.CI:
M:7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE"B`@("`@("`@("`@
M("DI.PH@("`@("`@("`@("`D9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H
M)&-O;G1E;G0I*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H)&-O;G1E;G0I
M.PH@("`@("`@('T*("`@('T*("`@(",@?7U]"@H@("`@(R!.;W<@=W)I=&4@
M;W5T('1H92!005(@86YD(&UA9VEC('-T<FEN9W,@>WM["B`@("`D>FEP+3YW
M<FET951O1FEL94AA;F1L92@D9F@I(&EF("1Z:7`["@H@("`@)&-A8VAE7VYA
M;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PH@("`@:68@*"$D8V%C
M:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U="DI6SE=*2!["B`@
M("`@("`@;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$
M:6=E<W0Z.E-(02T^;F5W*#$I('T*("`@("`@("`@("`@?'P@979A;"![(')E
M<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"B`@("`@
M("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z
M.DU$-2T^;F5W('T["@H@("`@("`@(",@5V]R:V%R;W5N9"!F;W(@8G5G(&EN
M($1I9V5S=#HZ4TA!(#4N,S@@86YD(#4N,SD*("`@("`@("!M>2`D<VAA7W9E
M<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*
M("`@("`@("!I9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E
M<G-I;VX@97$@)S4N,SDG*2!["B`@("`@("`@("`@("1C='@M/F%D9&9I;&4H
M)&]U="P@(F(B*2!I9B`H)&-T>"D["B`@("`@("`@?0H@("`@("`@(&5L<V4@
M>PH@("`@("`@("`@("!I9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)&]U
M="(I*2!["B`@("`@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@
M("`@("`@("`D8W1X+3YA9&1F:6QE*"1F:"D["B`@("`@("`@("`@("`@("!C
M;&]S92@D9F@I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D
M8V%C:&5?;F%M92`]("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64[
M"B`@("!]"B`@("`D8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H
M("1C86-H95]N86UE*3L*("`@("1C86-H95]N86UE("X](")#04-(12(["B`@
M("`D9F@M/G!R:6YT*"1C86-H95]N86UE*3L*("`@("1F:"T^<')I;G0H<&%C
M:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PH@("`@)&9H
M+3YP<FEN="@B7&Y005(N<&U<;B(I.PH@("`@)&9H+3YC;&]S93L*("`@(&-H
M;6]D(#`W-34L("1O=70["B`@("`C('U]?0H*("`@(&5X:70["GT*(R!]?7T*
M"B,@4')E<&%R92`D<')O9VYA;64@:6YT;R!005(@9FEL92!C86-H92![>WL*
M>PH@("`@;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PH*("`@(%]F
M:7A?<')O9VYA;64H*3L*"B`@("`C($YO=R!L;V%D('1H92!005(@9FEL92!A
M;F0@<'5T(&ET(&EN=&\@4$%2.CI,:6)#86-H92![>WL*("`@(')E<75I<F4@
M4$%2.PH@("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH*"B`@
M("!["B`@("`@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@
M:68@)%Y/(&YE("=-4U=I;C,R)SL*("`@("`@("!R97%U:7)E($9I;&4Z.D9I
M;F0["B`@("`@("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!]"B`@("!M
M>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B`@("!M>2`D9F@@/2!)3SHZ
M1FEL92T^;F5W.PH@("`@)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@
M;W(@9&EE("(D(3H@)$`B.PH@("`@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE
M*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@
M9&EE("(D(3H@)$`B.PH*("`@('!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`[
M"B`@("`D4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*"B`@("`D
M<75I970@/2`A)$5.5GM005)?1$5"54=].PH@("`@;W5T<RAQ<2A<)$5.5GM0
M05)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB*2D["@H@("`@:68@*&1E9FEN
M960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@
M<&]I;G0A"B`@("`@("`@9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M
M8F5R<R`I('L*("`@("`@("`@("`@;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C
M=&]R>3L*("`@("`@("`@("`@;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^
M9FEL94YA;64["B`@("`@("`@("`@(&YE>'0@=6YL97-S("1M96UB97)?;F%M
M92`]?B!M>PH@("`@("`@("`@("`@("`@7@H@("`@("`@("`@("`@("`@+S]S
M:&QI8B\*("`@("`@("`@("`@("`@("@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S
M:6]N?2\I/PH@("`@("`@("`@("`@("`@*#\Z)$-O;F9I9SHZ0V]N9FEG>V%R
M8VAN86UE?2\I/PH@("`@("`@("`@("`@("`@*%M>+UTK*0H@("`@("`@("`@
M("`@("`@)`H@("`@("`@("`@("!]>#L*("`@("`@("`@("`@;7D@)&5X=')A
M8W1?;F%M92`]("0Q.PH@("`@("`@("`@("!M>2`D9&5S=%]N86UE(#T@1FEL
M93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M
M92D["B`@("`@("`@("`@(&EF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@
M)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["B`@("`@("`@("`@("`@
M("!O=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L
M<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(BDI.PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@)&UE;6)E<BT^97AT<F%C=%1O1FEL
M94YA;65D*"1D97-T7VYA;64I.PH@("`@("`@("`@("`@("`@;W5T<RAQ<2A%
M>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H@("`@(R!]?7T*?0HC('U]
M?0H*(R!)9B!T:&5R92=S(&YO(&UA:6XN<&P@=&\@<G5N+"!S:&]W('5S86=E
M('M[>PIU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*("`@
M(&1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP
M87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O
M9W)A;2YP;"!="B`@("`@("`D,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C
M+G!A<@HN"B`@("`D14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D
M,"`]('-H:69T*$!!4D=6*3L*?0HC('U]?0H*<W5B($-R96%T95!A=&@@>PH@
M("`@;7D@*"1N86UE*2`]($!?.PH@("`@"B`@("!R97%U:7)E($9I;&4Z.D)A
M<V5N86UE.PH@("`@;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL
M93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PH@("`@
M"B`@("!R97%U:7)E($9I;&4Z.E!A=&@["B`@("`*("`@($9I;&4Z.E!A=&@Z
M.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE
M<R!W:71H(&5R<F]R"GT*"G-U8B!R97%U:7)E7VUO9'5L97,@>PH@("`@(VQO
M8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I
M;C,R)SL*"B`@("!R97%U:7)E(&QI8CL*("`@(')E<75I<F4@1'EN84QO861E
M<CL*("`@(')E<75I<F4@:6YT96=E<CL*("`@(')E<75I<F4@<W1R:6-T.PH@
M("`@<F5Q=6ER92!W87)N:6YG<SL*("`@(')E<75I<F4@=F%R<SL*("`@(')E
M<75I<F4@0V%R<#L*("`@(')E<75I<F4@0V%R<#HZ2&5A=GD["B`@("!R97%U
M:7)E($5X<&]R=&5R.CI(96%V>3L*("`@(')E<75I<F4@17AP;W)T97(["B`@
M("!R97%U:7)E($9C;G1L.PH@("`@<F5Q=6ER92!&:6QE.CI496UP.PH@("`@
M<F5Q=6ER92!&:6QE.CI3<&5C.PH@("`@<F5Q=6ER92!84TQO861E<CL*("`@
M(')E<75I<F4@0V]N9FEG.PH@("`@<F5Q=6ER92!)3SHZ2&%N9&QE.PH@("`@
M<F5Q=6ER92!)3SHZ1FEL93L*("`@(')E<75I<F4@0V]M<')E<W,Z.EIL:6([
M"B`@("!R97%U:7)E($%R8VAI=F4Z.EII<#L*("`@(')E<75I<F4@4$%2.PH@
M("`@<F5Q=6ER92!005(Z.DAE879Y.PH@("`@<F5Q=6ER92!005(Z.D1I<W0[
M"B`@("!R97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*("`@(&5V86P@
M>R!R97%U:7)E($-W9"!].PH@("`@979A;"![(')E<75I<F4@5VEN,S(@?3L*
M("`@(&5V86P@>R!R97%U:7)E(%=I;C,R.CI0<F]C97-S('T["B`@("!E=F%L
M('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*("`@(&5V86P@>R!R97%U:7)E
M($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PI]"@HC(%1H92!#('9E<G-I;VX@
M;V8@=&AI<R!C;V1E(&%P<&5A<G,@:6X@;7EL9'(O;6MT;7!D:7(N8PIS=6(@
M7W-E=%]P87)?=&5M<"!["B`@("!I9B`H)$5.5GM005)?5$5-4'T@86YD("1%
M3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PH@("`@("`@("1P87)?=&5M<"`]
M("0Q.PH@("`@("`@(')E='5R;CL*("`@('T*"B`@("!F;W)E86-H(&UY("1P
M871H("@*("`@("`@("`H;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!4
M35!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*("`@("`@("!Q=R@@0SI<7%1%
M35`@+W1M<"`N("D*("`@("D@>PH@("`@("`@(&YE>'0@=6YL97-S("1P871H
M(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["B`@("`@("`@;7D@)'5S97)N
M86UE.PH@("`@("`@(&UY("1P=W5I9#L*("`@("`@("`C(&1O97,@;F]T('=O
M<FL@979E<GEW:&5R93H*("`@("`@("!E=F%L('LH)'!W=6ED*2`](&=E='!W
M=6ED*"0^*2!I9B!D969I;F5D("0^.WT["@H@("`@("`@(&EF("@@9&5F:6YE
M9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B`@("`@("`@("`@("1U<V5R;F%M
M92`]("97:6XS,CHZ3&]G:6Y.86UE.PH@("`@("`@('T*("`@("`@("!E;'-I
M9B`H9&5F:6YE9"`D<'=U:60I('L*("`@("`@("`@("`@)'5S97)N86UE(#T@
M)'!W=6ED.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@
M)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G
M4UE35$5-)SL*("`@("`@("!]"B`@("`@("`@)'5S97)N86UE(#U^(',O7%<O
M7R]G.PH*("`@("`@("!M>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E
M;&EM?7!A<BTD=7-E<FYA;64B.PH@("`@("`@(&UK9&ER("1S=&UP9&ER+"`P
M-S4U.PH@("`@("`@(&EF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I
M;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PH@("`@("`@("`@("!O<&5N
M("AM>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*("`@("`@("`@("`@<V5E:R`D
M9F@L("TQ."P@,CL*("`@("`@("`@("`@<WES<F5A9"`D9F@L(&UY("1B=68L
M(#8["B`@("`@("`@("`@(&EF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PH@("`@
M("`@("`@("`@("`@<V5E:R`D9F@L("TU."P@,CL*("`@("`@("`@("`@("`@
M('-Y<W)E860@)&9H+"`D8G5F+"`T,3L*("`@("`@("`@("`@("`@("1B=68@
M/7X@<R]<,"\O9SL*("`@("`@("`@("`@("`@("1S=&UP9&ER("X]("(D0V]N
M9FEG>U]D96QI;7UC86-H92TB("X@)&)U9CL*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@(&UY("1C='@@/2!E=F%L
M('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]
M"B`@("`@("`@("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG97-T
M.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"B`@("`@("`@("`@("`@("`@
M("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U
M+3YN97<@?3L*"B`@("`@("`@("`@("`@("`C(%=O<FMA<F]U;F0@9F]R(&)U
M9R!I;B!$:6=E<W0Z.E-(02`U+C,X(&%N9"`U+C,Y"B`@("`@("`@("`@("`@
M("!M>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)3
M24].('T@?'P@,#L*("`@("`@("`@("`@("`@(&EF("@D<VAA7W9E<G-I;VX@
M97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*("`@("`@
M("`@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1P<F]G;F%M92P@(F(B*2!I
M9B`H)&-T>"D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!E
M;'-E('L*("`@("`@("`@("`@("`@("`@("!I9B`H)&-T>"!A;F0@;W!E;BAM
M>2`D9F@L("(\)'!R;V=N86UE(BDI('L*("`@("`@("`@("`@("`@("`@("`@
M("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("`@("`@("`@("`@("`D8W1X
M+3YA9&1F:6QE*"1F:"D["B`@("`@("`@("`@("`@("`@("`@("`@(&-L;W-E
M*"1F:"D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@("`@("1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI
M;7UC86-H92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE
M("D["B`@("`@("`@("`@('T*("`@("`@("`@("`@8VQO<V4H)&9H*3L*("`@
M("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@("1%3E9[4$%27T-,
M14%.?2`](#$["B`@("`@("`@("`@("1S=&UP9&ER("X]("(D0V]N9FEG>U]D
M96QI;7UT96UP+20D(CL*("`@("`@("!]"@H@("`@("`@("1%3E9[4$%27U1%
M35!](#T@)'-T;7!D:7(["B`@("`@("`@;6MD:7(@)'-T;7!D:7(L(#`W-34[
M"B`@("`@("`@;&%S=#L*("`@('T*"B`@("`D<&%R7W1E;7`@/2`D,2!I9B`D
M14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]
M"@IS=6(@7W1E;7!F:6QE('L*("`@(&UY("@D97AT+"`D8W)C*2`]($!?.PH@
M("`@;7D@*"1F:"P@)&9I;&5N86UE*3L*"B`@("`D9FEL96YA;64@/2`B)'!A
M<E]T96UP+R1C<F,D97AT(CL*"B`@("!I9B`H)$5.5GM005)?0TQ%04Y]*2![
M"B`@("`@("`@=6YL:6YK("1F:6QE;F%M92!I9B`M92`D9FEL96YA;64["B`@
M("`@("`@<'5S:"!`=&UP9FEL92P@)&9I;&5N86UE.PH@("`@?0H@("`@96QS
M92!["B`@("`@("`@<F5T=7)N("AU;F1E9BP@)&9I;&5N86UE*2!I9B`H+7(@
M)&9I;&5N86UE*3L*("`@('T*"B`@("!O<&5N("1F:"P@)SXG+"`D9FEL96YA
M;64@;W(@9&EE("0A.PH@("`@8FEN;6]D92@D9F@I.PH@("`@<F5T=7)N*"1F
M:"P@)&9I;&5N86UE*3L*?0H*<W5B(%]S971?<')O9VYA;64@>PH@("`@:68@
M*"1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^
M("\H+BLI+RD@>PH@("`@("`@("1P<F]G;F%M92`]("0Q.PH@("`@?0H*("`@
M("1P<F]G;F%M92!\?#T@)#`["@H@("`@:68@*"1%3E9[4$%27U1%35!](&%N
M9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B`@
M("`@("`@)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P
M<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PH@("`@?0H*("`@(&EF
M("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O
M;F9I9WM?9&5L:6U]*2`^/2`P*2!["B`@("`@("`@:68@*&]P96X@;7D@)&9H
M+"`G/"<L("1P<F]G;F%M92D@>PH@("`@("`@("`@("!R971U<FX@:68@+7,@
M)&9H.PH@("`@("`@('T*("`@("`@("!I9B`H+7,@(B1P<F]G;F%M921#;VYF
M:6=[7V5X97TB*2!["B`@("`@("`@("`@("1P<F]G;F%M92`N/2`D0V]N9FEG
M>U]E>&5].PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H@("`@?0H*
M("`@(&9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP871H7W-E
M<'U<12\L("1%3E9[4$%42'TI('L*("`@("`@("!N97AT(&EF(&5X:7-T<R`D
M14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*("`@
M("`@("`D9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O+SL*("`@("`@
M("`H*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE
M)$-O;F9I9WM?97AE?2(I+"!L87-T*0H@("`@("`@("`@("!I9B`M<R`B)&1I
M<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB.PH@("`@
M("`@("@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA
M;64B*2P@;&%S="D*("`@("`@("`@("`@:68@+7,@(B1D:7(D0V]N9FEG>U]D
M96QI;7TD<')O9VYA;64B.PH@("`@?0I]"@IS=6(@7V9I>%]P<F]G;F%M92![
M"B`@("`D,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PH@
M("`@:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`\(#`I
M('L*("`@("`@("`D<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM?21P<F]G
M;F%M92(["B`@("!]"@H@("`@(R!86%@@+2!H86-K('1O(&UA:V4@4%=$('=O
M<FL*("`@(&UY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D
M.CIG971C=V0H*0H@("`@("`@("`@("`@("`@.B`H*&1E9FEN960@)E=I;C,R
M.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PH@("`@8VAO
M;7`H)'!W9"D["B`@("`D<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF
M:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*"B`@("`D14Y6
M>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*"G-U8B!?<&%R7VEN:71?
M96YV('L*("`@(&EF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I
M('L*("`@("`@("!R971U<FX["B`@("!](&5L<V4@>PH@("`@("`@("1%3E9[
M4$%27TE.251)04Q)6D5$?2`](#(["B`@("!]"@H@("`@9F]R("AQ=R@@4U!!
M5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%($%21T,@05)'
M5E\P("D@*2!["B`@("`@("`@9&5L971E("1%3E9[)U!!4E\G+B1??3L*("`@
M('T*("`@(&9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*
M("`@("`@("`D14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N
M)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PH@("`@?0H*
M("`@(&UY("1P87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@("`@
M("`@("`@("`B.PH*("`@(&EF("@D14Y6>U!!4E]414U0?2D@>PH@("`@("`@
M(&1E;&5T92`D14Y6>U!!4E]#3$5!3GT["B`@("!]"B`@("!E;'-I9B`H(65X
M:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2!["B`@("`@("`@;7D@)'9A
M;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H*")#3$5!3B(I
M*3L*("`@("`@("`D14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@
M+UY005)?0TQ%04X]*%Q3*RDO.PH@("`@?0I]"@IS=6(@;W5T<R!["B`@("!R
M971U<FX@:68@)'%U:65T.PH@("`@:68@*"1L;V=F:"D@>PH@("`@("`@('!R
M:6YT("1L;V=F:"`B0%]<;B(["B`@("!]"B`@("!E;'-E('L*("`@("`@("!P
M<FEN="`B0%]<;B(["B`@("!]"GT*"G-U8B!I;FET7VEN8R!["B`@("!R97%U
M:7)E($-O;F9I9SL*("`@('!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@
M)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"B`@("`@("`@87)C:&QI8F5X<"!P
M<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*("`@("`@("!V96YD
M;W)A<F-H97AP('9E;F1O<FQI8F5X<`H@("`@*3L*?0H*(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C"B,@5&AE(&UA:6X@<&%C:V%G92!F;W(@<V-R:7!T
M(&5X96-U=&EO;@H*<&%C:V%G92!M86EN.PH*<F5Q=6ER92!005(["G5N<VAI
M9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R
M9W,I.PH*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B
M)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0H@("`@
M=6YL97-S("UE("1P<F]G;F%M93L*"F1O("1P<F]G;F%M93L*0T]213HZ97AI
M="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`
M(&EF("1`.PH*?3L*"B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0H*0T]213HZ
M97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<
M*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PH*,3L*"B-L:6YE
M(#$P,C$*"E]?14Y$7U\*`'!A<BYP;````````/____\0.T``)#M``-"@````
M`````````):C``"H0```,*``````````````VJ,```A````HH```````````
M``#XHP```$```$"@`````````````/RD```80```````````````````````
M``````#HHP```````,:C``"XHP``HJ,```````"&I0``=J4``&:E``!2I0``
M1J4``#:E```FI0``'J4``!"E```(I0``\*0``.:D``#8I```S*0``,*D``"4
MI0``JJ0``*"D``"6I```AJ0``'JD``!PI```9J0``%RD``!2I```2*0``#BD
M```NI```)*0``!JD```0I```!J0``*:E``"ZI0``M*0```````""HP``<*,`
M`%JC``!,HP``.J,``!JC```"HP``\*(``-JB``#,H@``P*(``+"B``"DH@``
ME*(``("B``!NH@``7J(``$JB```ZH@``*J(``!RB```(H@``^*$``."A``#.
MH0``OJ$``*ZA``":H0``B*$``'2A``!FH0``5*$```````"F!&)O;W1?5VEN
M,S)#3U)%``!'`U!E<FQ?;F5W6%,``%0"4&5R;%]G971?8V]N=&5X=```I01B
M;V]T7T1Y;F%,;V%D97(`FP%097)L7TES=&%T8G5F7W!T<@#!`%!E<FQ?24Q)
M3U]P='(`Q`!097)L7TE-96U?<'1R`,@`4&5R;%])4')O8U]P='(``!8"4&5R
M;%]C<F]A:U]N;V-O;G1E>'0``+\`4&5R;%])1&ER7W!T<@#D`%!E<FQ?26-O
M;7!C=E]P='(``/4"4&5R;%]M9U]S970`.01097)L7W-V7W-E='!V```"4&5R
M;%]A=E]S:&EF=`#G`U!E<FQ?<W9?,G!V7V9L86=S`/D!4&5R;%]A=E]F971C
M:`!X`E!E<FQ?9W9?9F5T8VAP=@"P`5!E<FQ?271A:6YT961?<'1R`&P$4&5R
M;%]S>7-?=&5R;0"P!'!E<FQ?9G)E90"O!'!E<FQ?9&5S=')U8W0`LP1P97)L
M7W)U;@``L@1P97)L7W!A<G-E``";`U!E<FQ?<V%F97-Y<VUA;&QO8P``!`!0
M3%]M96UO<GE?=W)A<```$P%097)L7TEE>&ET7V9L86=S7W!T<@``:@%097)L
M7TEP97)L7V1E<W1R=6-T7VQE=F5L7W!T<@"N!'!E<FQ?8V]N<W1R=6-T``"H
M!'!E<FQ?86QL;V,``)@`4&5R;%]'9&]?=6YD=6UP7W!T<@!H!%!E<FQ?<WES
M7VEN:70S``!(`U!E<FQ?;F5W6%-?9FQA9W,``'!E<FPU,3`N9&QL`'4!1V5T
M36]D=6QE1FEL94YA;65!``#O`$9R965,:6)R87)Y`'<!1V5T36]D=6QE2&%N
M9&QE00``2T523D5,,S(N9&QL```C`4=E=%5S97).86UE00``041605!),S(N
M9&QL``"R`G-P<FEN=&8`N`)S=')C;7```,<"<W1R=&]K``"^`G-T<FQE;@``
MQ0)S=')S='(``&T`7U]P7U]E;G9I<F]N``"8`FUE;6UO=F4`P0)S=')N8W!Y
M`,`"<W1R;F-M<`""`5]M:V1I<@``C@%?<&-T>7!E`!4!7VES8W1Y<&4``&$`
M7U]M8E]C=7)?;6%X``"7`FUE;6-P>0``F0)M96US970``)D!7W)M9&ER``#?
M`%]F:6YD8VQO<V4``-T!7W5N;&EN:P#B`%]F:6YD;F5X=`#@`%]F:6YD9FER
M<W0``+\!7W-T<F1U<`#%`5]S=')N:6-M<`!-4U9#4E0N9&QL``#3`%]E>&ET
M`$@`7UAC<'1&:6QT97(`20)E>&ET``!D`%]?<%]?7VEN:71E;G8`6`!?7V=E
M=&UA:6YA<F=S``\!7VEN:71T97)M`(,`7U]S971U<V5R;6%T:&5R<@``G0!?
M861J=7-T7V9D:78``&H`7U]P7U]C;VUM;V1E``!O`%]?<%]?9FUO9&4``($`
M7U]S971?87!P7W1Y<&4``,H`7V5X8V5P=%]H86YD;&5R,P``MP!?8V]N=')O
M;&9P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````4$%``$Q!0`#_____K)]``(M;
M```````````````````!````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````#``,````H``"`#@```$@``(`0
M````8```@````````````````````@`!````>```@`(```"0``"`````````
M```````````!`&4```"H``"````````````````````!``$```#```"`````
M```````````````!``````#8```````````````````````!``````#H````
M```````````````````!``````#X```````````````````````!```````(
M`0``F,,``&@%``````````````#)``"H"`````````````"HT0``(@``````
M````````(,$``'0"````````````````````````=`(T````5@!3`%\`5@!%
M`%(`4P!)`$\`3@!?`$D`3@!&`$\``````+T$[_X```$`````````````````
M`````#\````!````!``$``$```````````````````#4`0```0!3`'0`<@!I
M`&X`9P!&`&D`;`!E`$D`;@!F`&\```"P`0```0`P`#0`,``P`#``-`!B`#``
M```8`````0!#`&\`;0!M`&4`;@!T`',````@`````0!#`&\`;0!P`&$`;@!Y
M`$X`80!M`&4``````"@````!`$8`:0!L`&4`1`!E`',`8P!R`&D`<`!T`&D`
M;P!N```````@`````0!&`&D`;`!E`%8`90!R`',`:0!O`&X``````"`````!
M`$D`;@!T`&4`<@!N`&$`;`!.`&$`;0!E````)`````$`3`!E`&<`80!L`$,`
M;P!P`'D`<@!I`&<`:`!T````*`````$`3`!E`&<`80!L`%0`<@!A`&0`90!M
M`&$`<@!K`',``````"@````!`$\`<@!I`&<`:0!N`&$`;`!&`&D`;`!E`&X`
M80!M`&4````@`````0!0`'(`:0!V`&$`=`!E`$(`=0!I`&P`9````"`````!
M`%``<@!O`&0`=0!C`'0`3@!A`&T`90``````)`````$`4`!R`&\`9`!U`&,`
M=`!6`&4`<@!S`&D`;P!N````(`````$`4P!P`&4`8P!I`&$`;`!"`'4`:0!L
M`&0```!$`````0!6`&$`<@!&`&D`;`!E`$D`;@!F`&\``````"0`!````%0`
M<@!A`&X`<P!L`&$`=`!I`&\`;@````````2P!``````H````$````"`````!
M``@````````!```````````````!`````0``!@8&``0$!``"`@(``````$)"
M0@"=G9T`;FYN`(&!@0"QL;$`____`'-S<P"?GY\`6%A8`+*RL@#]_?T`:VMK
M`/S\_`#7U]<`%A86`-K:V@"6EI8`CHZ.`$9&1@#+R\L`"PL+`*"@H`#^_OX`
MR<G)`,'!P0`#`P,`$1$1`).3DP"SL[,`[N[N`/3T]`#CX^,`Y>7E`**BH@"Z
MNKH`KZ^O``<'!P!Q<7$`M;6U`/7U]0")B8D`BHJ*`#0T-`#HZ.@`-34U`%I:
M6@"WM[<`V-C8`-#0T``='1T`#`P,`(^/CP"^OKX`;6UM``D)"0";FYL`+R\O
M`,W-S0#9V=D`&1D9`$U-30!$1$0`4%!0`#P\/`!D9&0`PL+"`#(R,@`("`@`
M#0T-``\/#P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````%!04%!04%!04%!04%!00$!`35`(P5!,4-!041%
M+@$!`0$!`0$%`3P7%P$!$P$!`0$!`0$!%0$!)A4!`0\!`0$!`0$!`1,!$0$%
M-0$F`0$!`0$!`0$B$A`Q#P4!(`$!`0$!`0$!$`H@(A45+B$N`0$!`0$?("$0
M(A`C(R4F)P$!`0$E$!`0$!`0$!`0%T4!`0%!$!`0$!`0$!`0$!`7`0$!#Q`0
M%1`0$!`0$!`0`0$!`1(0$!,?$!`0$!`0!P$!`0$@$!`0`0\0$!`0$0$!`0$!
M!R`0"@$!!1`0$#$!`0$!`0$!`0$!`0%!!0\!`0$!`0$!`0$!`0$!`0$!`0$!
M`0&``0``P`$``.`#``#P`P``\`,``/`#``#@`P``P`$``(`!``"``0``@`,`
M`(`#````!P````<``(X/``#_'P``*````"````!``````0`(````````!```
M`````````````0````$````````!`0$``@("``,#`P`$!`0`!04%``8&!@`'
M!P<`"`@(``D)"0`*"@H`"PL+``P,#``-#0T`#@X.``\/#P`0$!``$1$1`!(2
M$@`3$Q,`%!04`!45%0`6%A8`%Q<7`!@8&``9&1D`&AH:`!L;&P`<'!P`'1T=
M`!X>'@`?'Q\`("`@`"$A(0`B(B(`(R,C`"0D)``E)24`)B8F`"<G)P`H*"@`
M*2DI`"HJ*@`K*RL`+"PL`"TM+0`N+BX`+R\O`#`P,``Q,3$`,C(R`#,S,P`T
M-#0`-34U`#8V-@`W-S<`.#@X`#DY.0`Z.CH`.SL[`#P\/``]/3T`/CX^`#\_
M/P!`0$``04%!`$)"0@!#0T,`1$1$`$5%10!&1D8`1T='`$A(2`!)24D`2DI*
M`$M+2P!,3$P`34U-`$Y.3@!/3T\`4%!0`%%140!24E(`4U-3`%145`!5554`
M5E96`%=75P!86%@`65E9`%I:6@!;6UL`7%Q<`%U=70!>7EX`7U]?`&!@8`!A
M86$`8F)B`&-C8P!D9&0`965E`&9F9@!G9V<`:&AH`&EI:0!J:FH`:VMK`&QL
M;`!M;6T`;FYN`&]O;P!P<'``<7%Q`')R<@!S<W,`='1T`'5U=0!V=G8`=W=W
M`'AX>`!Y>7D`>GIZ`'M[>P!\?'P`?7U]`'Y^?@!_?W\`@("``(&!@0""@H(`
M@X.#`(2$A`"%A84`AH:&`(>'AP"(B(@`B8F)`(J*B@"+BXL`C(R,`(V-C0".
MCHX`CX^/`)"0D`"1D9$`DI*2`).3DP"4E)0`E965`):6E@"7EY<`F)B8`)F9
MF0":FIH`FYN;`)R<G`"=G9T`GIZ>`)^?GP"@H*``H:&A`**BH@"CHZ,`I*2D
M`*6EI0"FIJ8`IZ>G`*BHJ`"IJ:D`JJJJ`*NKJP"LK*P`K:VM`*ZNK@"OKZ\`
ML+"P`+&QL0"RLK(`L[.S`+2TM`"UM;4`MK:V`+>WMP"XN+@`N;FY`+JZN@"[
MN[L`O+R\`+V]O0"^OKX`O[^_`,#`P`#!P<$`PL+"`,/#PP#$Q,0`Q<7%`,;&
MQ@#'Q\<`R,C(`,G)R0#*RLH`R\O+`,S,S`#-S<T`SL[.`,_/SP#0T-``T='1
M`-+2T@#3T],`U-34`-75U0#6UM8`U]?7`-C8V`#9V=D`VMK:`-O;VP#<W-P`
MW=W=`-[>W@#?W]\`X.#@`.'AX0#BXN(`X^/C`.3DY`#EY>4`YN;F`.?GYP#H
MZ.@`Z>GI`.KJZ@#KZ^L`[.SL`.WM[0#N[NX`[^_O`/#P\`#Q\?$`\O+R`//S
M\P#T]/0`]?7U`/;V]@#W]_<`^/CX`/GY^0#Z^OH`^_O[`/S\_`#]_?T`_O[^
M`/___P`T-#0\/#P\/#P\/#P\/#P\/#P\/#P\/#PL#`0$!`0$!%RTU-34U-34
MU-34U-S4U-34U-34U-34U+0T400$!`0$9,SL]/3T_/3\]/3T_/3\]/ST_/S\
M]/3LQ#11400$!`1DQ.3L]/3T]/3T]/3T]/3T]/3T]/3T[.R\-%%1400$!&3$
MY.SL[.3L[.SDY.3D[.SD[.3L[.SLY+PT45%1400$9+SD[.RLC*S4Q)24G)2,
MC)24E)R<G.S<O#1145%1401DO-SD[.3$492L9.2D3#0L7,3,4;34Y-R\-%%1
M45%1462\W.3D[.3D481TY(QLI)QLC+QTK-3DW+PT!`0$!`0$9+S<Y.3LY.2\
M48S4U(RLS'3,W*11Q.3<O#0$!`0$!`1DO-SDY.3DY-R,?)RT?(2<;,SDO'3$
MY-RT-`0$!`0$!%R\W-SDY.3DU)RD7)2,S#R49,R\C%'<U+0T!`0$!`0$9+34
MW-S<Y-R,C*PLO+3,6L1DG&R4I-S4M#0$!`0$!`1<M-3<W.3<W'24U$RD](P\
MU'24=)Q,W,RT-`0$!`0$!&2TU-S<W.3<=%'T=(3LS&3D?&RDM&RDU+0T!`0$
M!`0$9+3,W-S,?(R$M/S,Q/STM/R\9,RLA%&\K#0$!`0$!`1<M,S4S(RDW-SL
M_/S\_/ST_.RT[*Q\E%&L-`0$!`0$!%RLS,QLG/3\_/S\_/S\_/S\_/S\Q)2,
M4:PT!`0$!`0$7*S$O'SD_/S\_/S\_/S\_/S\_/SLS*Q1K#0$!`0$!`1<K+1,
MQ/S\_.ST_/S\_/S\_/S\_/2\4<2L-`0$!`0$!%RLM$S4_/STM-S\_/S\_/S\
M_/S\S%',Q*0T!`0$!`0$7*S$I%'\_/RTG/3\_/S\_/S\_/244<S$I"P$!`0$
M!`1<I*11A.S\_,QDM.S\_/S\_/S\U&RLS+RD-`0$!`0$!%RD9'2\]/S\Q%&$
MG.3\_/S\_.2,4<S,Q*0T!`0$!`0$7*1LC.3T_/R<4<Q1E.S\_/S\O'3,S,2\
MG"P$!`0$!`1<I*QD7&2DI%&LS,1TE.3T_.11O,S,Q+R<-`0$!`0$!%RDM+R\
MC%%1Q,3,S*Q1?'R4;'R\S,3$O)PL!`0$!`0$7)R\Q,3$Q,3$Q,3$Q,1145%1
MO,3$Q,2TG#0$!`0$!`14G+3$Q,3$Q,3$Q,3$Q,3$Q,3$Q,3$O+2<+`0$!`0$
M!%2<O,3$O+R\O+R\O+R\O+R\O+R\O+R\M)PL!`0$!`0$7)RTQ+RTM+2TM+2T
MM+2TM+2TM+2TM+2LG"P$!`0$!`14A)2<G)24E)24E)24E)24E)24E)24E)2$
M)`0$!`0$!$147%Q<7%Q<7%Q<7%Q<7%Q<7%Q<7%Q<7%0T!`0$!`0$````/P``
M`!\````/````!P````,````!`````````#\````_````/P```#\````_````
M/P```#\````_````/P```#\````_````/P```#\````_````/P```#\````_
M````/P```#\````_````/P```#\````_````/P```#\```$``@`0$````0`(
M`&@%```!`"`@```!``@`J`@```(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!.0C$P`````!XM*T@!````0SI<4$%27&)U:6QD7#4N
B,3!<4$%2+5!A8VME<BTP+CDX,%QM>6QD<EQP87(N<&1B````
